@@ -62,7 +62,7 @@ function action_logout_dist() {
 			$texte = bouton_action(_T('spip:icone_deconnecter'), $action);
 			$texte = "<div class='boutons'>$texte</div>";
 			$texte .= '<script type="text/javascript">document.write("<style>body{visibility:hidden;}</style>");window.document.forms[0].submit();</script>';
-			$res = minipres(_T('spip:icone_deconnecter'), $texte, '', true);
+			$res = minipres(_T('spip:icone_deconnecter'), $texte, ['all_inline' => true]);
 			echo $res;
 
 			return;
@@ -99,7 +99,7 @@ function action_logout_dist() {
 	// Rediriger en contrant le cache navigateur (Safari3)
 	include_spip('inc/headers');
 	redirige_par_entete($url
-		? parametre_url($url, 'var_hasard', uniqid(rand()), '&')
+		? parametre_url($url, 'var_hasard', uniqid(random_int(0, mt_getrandmax())), '&')
 		: generer_url_public('login'));
 }
 
