@@ -52,7 +52,7 @@ if (!isset($GLOBALS['ldap_attributes']) or !is_array($GLOBALS['ldap_attributes']
  * @param string $pass
  * @param string $serveur
  * @param bool $phpauth
- * @return string
+ * @return array|bool
  */
 function auth_ldap_dist($login, $pass, $serveur = '', $phpauth = false) {
 
@@ -86,7 +86,7 @@ function auth_ldap_dist($login, $pass, $serveur = '', $phpauth = false) {
 		$desc['source'] = 'ldap';
 		$desc['pass'] = '';
 
-		$r = sql_insertq('spip_auteurs', $desc, '', $serveur);
+		$r = sql_insertq('spip_auteurs', $desc, [], $serveur);
 	}
 
 	if ($r) {
@@ -167,9 +167,9 @@ function auth_ldap_search($login, $pass, $checkpass = true, $serveur = '') {
 		return '';
 	}
 
-	$ldap_link = isset($ldap['link']) ? $ldap['link'] : null;
-	$ldap_base = isset($ldap['base']) ? $ldap['base'] : null;
-	$desc = isset($ldap['attributes']) && $ldap['attributes'] ? $ldap['attributes'] : $GLOBALS['ldap_attributes'] ;
+	$ldap_link = $ldap['link'] ?? null;
+	$ldap_base = $ldap['base'] ?? null;
+	$desc = !empty($ldap['attributes']) ? $ldap['attributes'] : $GLOBALS['ldap_attributes'];
 
 	$logins = is_array($desc['login']) ? $desc['login'] : [$desc['login']];
 
@@ -215,7 +215,7 @@ function auth_ldap_search($login, $pass, $checkpass = true, $serveur = '') {
 function auth_ldap_retrouver($dn, $desc = [], $serveur = '') {
 	// Lire les infos sur l'utilisateur a partir de son DN depuis LDAP
 
-	if (!$ldap = spip_connect_ldap($serveur)) {
+	if (!$ldap = auth_ldap_connect($serveur)) {
 		spip_log("ldap $serveur injoignable");
 
 		return [];
@@ -223,7 +223,7 @@ function auth_ldap_retrouver($dn, $desc = [], $serveur = '') {
 
 	$ldap_link = $ldap['link'];
 	if (!$desc) {
-		$desc = $ldap['attributes'] ? $ldap['attributes'] : $GLOBALS['ldap_attributes'];
+		$desc = $ldap['attributes'] ?: $GLOBALS['ldap_attributes'];
 		unset($desc['login']);
 	}
 	$result = @ldap_read($ldap_link, $dn, 'objectClass=*', array_values($desc));
@@ -323,7 +323,7 @@ function auth_ldap_modifier_pass($login, $new_pass, $id_auteur, $serveur = '') {
 		return false;
 	}
 	if (!$ldap = auth_ldap_connect($serveur)) {
-		return '';
+		return false;
 	}
 	$link = $ldap['link'];
 	include_spip('inc/session');
