@@ -72,27 +72,36 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 	$cles = SpipCles::instance();
 	$secret = $cles->getSecretAuth();
 
+	$hash = null;
 	switch (strlen($row['pass'])) {
+		// legacy = md5 ou sha256
 		case 32:
 			// tres anciens mots de passe encodes en md5(alea.pass)
-			$md5pass = md5($row['alea_actuel'] . $pass);
-			if ($row['pass'] !== $md5pass) {
-				unset($row);
-			}
-			break;
+			$hash = md5($row['alea_actuel'] . $pass);
+			$methode = 'md5';
 		case 64:
-			// anciens mots de passe encodes en sha256(alea.pass)
-			include_spip('auth/sha256.inc');
-			$shapass = spip_sha256($row['alea_actuel'] . $pass);
-			if ($row['pass'] !== $shapass) {
-				unset($row);
+			if (empty($hash)) {
+				// anciens mots de passe encodes en sha256(alea.pass)
+				include_spip('auth/sha256.inc');
+				$hash = spip_sha256($row['alea_actuel'] . $pass);
+				$methode = 'sha256';
 			}
-			break;
+			if ($row['pass'] === $hash) {
+				spip_log("validation du mot de passe pour l'auteur #" . $row['id_auteur'] . " $login via $methode", 'auth' . _LOG_DEBUG);
+				// ce n'est pas cense arriver, mais si jamais c'est un backup inutilisable, il faut le nettoyer pour ne pas bloquer la creation d'une nouvelle cle d'auth
+				if (!empty($row['backup_cles'])) {
+					sql_updateq('spip_auteurs', ['backup_cles' => ''], 'id_auteur=' . intval($row['id_auteur']));
+				}
+				break;
+			}
+
+		// on teste la methode par defaut, au cas ou ce serait un pass moderne qui a la malchance d'etre en 64char de long
 
 		case 60:
 		case 98:
 		default:
 			// doit-on restaurer un backup des cles ?
+			// si on a le bon pass on peut decoder le backup, retrouver la cle, et du coup valider le pass
 			if (
 				!$secret
 				and $auteur_peut_sauver_cles
@@ -100,7 +109,14 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 			) {
 				if ($cles->restore($row['backup_cles'], $pass, $row['pass'], $row['id_auteur'])) {
 					spip_log('Les cles secretes ont ete restaurées avec le backup du webmestre #' . $row['id_auteur'], 'auth' . _LOG_INFO_IMPORTANTE);
-					$cles->save();
+					if ($cles->save()) {
+						$secret = $cles->getSecretAuth();
+					}
+					else {
+						spip_log("Echec restauration des cles : verifier les droits d'ecriture ?", 'auth' . _LOG_ERREUR);
+						// et on echoue car on ne veut pas que la situation reste telle quelle
+						raler_fichier(_DIR_ETC . 'cles.php');
+					}
 				}
 				else {
 					spip_log('Pas de cle secrete disponible (fichier config/cle.php absent ?) mais le backup du webmestre #' . $row['id_auteur'] . " n'est pas valide", 'auth' . _LOG_ERREUR);
@@ -111,6 +127,9 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 			if (!$secret or !Password::verifier($pass, $row['pass'], $secret)) {
 				unset($row);
 			}
+			else {
+				spip_log("validation du mot de passe pour l'auteur #" . $row['id_auteur'] . " $login via Password::verifier", 'auth' . _LOG_DEBUG);
+			}
 			break;
 	}
 
@@ -200,13 +219,17 @@ function auth_spip_initialiser_secret(bool $force = false): bool {
 	$has_backup = array_column($has_backup, 'id_auteur');
 	if (empty($has_backup)) {
 		spip_log("Pas de cle secrete disponible, et aucun webmestre n'a de backup, on regenere une nouvelle cle - tous les mots de passe sont invalides", 'auth' . _LOG_INFO_IMPORTANTE);
-		$secret = $cles->getSecretAuth(true);
-		return true;
+		if ($secret = $cles->getSecretAuth(true)) {
+			return true;
+		}
+		spip_log("Echec generation d'une nouvelle cle : verifier les droits d'ecriture ?", 'auth' . _LOG_ERREUR);
+		// et on echoue car on ne veut pas que la situation reste telle quelle
+		raler_fichier(_DIR_ETC . 'cles.php');
 	}
 	else {
 		spip_log('Pas de cle secrete disponible (fichier config/cle.php absent ?) un des webmestres #' . implode(', #', $has_backup) . ' doit se connecter pour restaurer son backup des cles', 'auth' . _LOG_ERREUR);
-		return false;
 	}
+	return false;
 }
 
 /**
