@@ -29,7 +29,7 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 }
 
 /** Version de l'API SQL */
-define('sql_ABSTRACT_VERSION', 1);
+define('SQL_ABSTRACT_VERSION', 1);
 include_spip('base/connect_sql');
 
 /**
@@ -104,7 +104,7 @@ function sql_error_backtrace($compil_info = false) {
 function sql_serveur($ins_sql = '', $serveur = '', $continue = false) {
 	static $sql_serveur = [];
 	if (!isset($sql_serveur[$serveur][$ins_sql])) {
-		$f = spip_connect_sql(sql_ABSTRACT_VERSION, $ins_sql, $serveur, $continue);
+		$f = spip_connect_sql(\SQL_ABSTRACT_VERSION, $ins_sql, $serveur, $continue);
 		if (!is_string($f) or !$f) {
 			return $f;
 		}
@@ -134,8 +134,8 @@ function sql_serveur($ins_sql = '', $serveur = '', $continue = false) {
  **/
 function sql_get_charset($charset, $serveur = '', $option = true) {
 	// le nom http du charset differe parfois du nom SQL utf-8 ==> utf8 etc.
-	$desc = sql_serveur('', $serveur, true, true);
-	$desc = $desc[sql_ABSTRACT_VERSION];
+	$desc = sql_serveur('', $serveur, true);
+	$desc = $desc[\SQL_ABSTRACT_VERSION];
 	$c = $desc['charsets'][$charset];
 	if ($c) {
 		if (function_exists($f = @$desc['get_charset'])) {
@@ -204,8 +204,8 @@ function sql_set_charset($charset, $serveur = '', $option = true) {
  *     Tableau de classement (Order By)
  * @param string $limit
  *     Critere de limite (Limit)
- * @param array $having
- *     Tableau des des post-conditions a remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *     Le serveur sollicite (pour retrouver la connexion)
  * @param bool|string $option
@@ -266,7 +266,7 @@ function sql_select(
 		}
 		// le debug, c'est pour ce qui a ete produit par le compilateur
 		if (isset($GLOBALS['debug']['aucasou'])) {
-			list($table, $id, ) = $GLOBALS['debug']['aucasou'];
+			[$table, $id, ] = $GLOBALS['debug']['aucasou'];
 			$nom = $GLOBALS['debug_objets']['courant'] . $id;
 			$GLOBALS['debug_objets']['requete'][$nom] = $query;
 		}
@@ -309,8 +309,8 @@ function sql_select(
  *    Tableau de classement (Order By)
  * @param string $limit
  *    Critere de limite (Limit)
- * @param array $having
- *    Tableau des des post-conditions a remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *    Le serveur sollicite (pour retrouver la connexion)
  *
@@ -356,8 +356,8 @@ function sql_get_select(
  *    Conditions a remplir (Where)
  * @param array|string $groupby
  *    Critere de regroupement (Group by)
- * @param array $having
- *    Tableau des des post-conditions a remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *    Le serveur sollicite (pour retrouver la connexion)
  * @param bool|string $option
@@ -612,7 +612,7 @@ function sql_selectdb($nom, $serveur = '', $option = true) {
  * @see sql_select()
  * @see sql_countsel()
  *
- * @param Ressource $res
+ * @param Object $res
  *     Ressource SQL
  * @param string $serveur
  *     Nom du connecteur
@@ -644,7 +644,7 @@ function sql_count($res, $serveur = '', $option = true) {
  * Indique au gestionnaire SQL de libérer de sa mémoire la ressoucre de
  * résultat indiquée car on n'a plus besoin de l'utiliser.
  *
- * @param Ressource|Object $res
+ * @param Object $res
  *     Ressource de résultat
  * @param string $serveur
  *     Nom de la connexion
@@ -1092,7 +1092,7 @@ function sql_drop_table($table, $exist = '', $serveur = '', $option = true) {
  * @param string $table Nom de la vue SQL
  * @param string $exist True pour ajouter un test d'existence avant de supprimer
  * @param string $serveur Nom de la connexion
- * @param bool $option
+ * @param bool|string $option
  *     Peut avoir 3 valeurs :
  *
  *     - false : ne pas l'exécuter mais la retourner,
@@ -1132,7 +1132,7 @@ function sql_drop_view($table, $exist = '', $serveur = '', $option = true) {
  *     - false -> ne pas l'executer mais la retourner,
  *     - continue -> ne pas echouer en cas de serveur sql indisponible,
  *     - true -> executer la requete.
- * @return ressource
+ * @return object|bool|string
  *     Ressource à utiliser avec sql_fetch()
  **/
 function sql_showbase($spip = null, $serveur = '', $option = true) {
@@ -1238,6 +1238,49 @@ function sql_showtable($table, $table_spip = false, $serveur = '', $option = tru
 	return $f;
 }
 
+
+/**
+ * Teste si une table SQL existe ou non dans la base
+ *
+ * @api
+ *
+ * @param string $table
+ *     Nom de la table
+* @param bool $table_spip
+ *     true pour remplacer automatiquement « spip » par le vrai préfixe de table
+ * @param string $serveur
+ *     Nom du connecteur
+ * @param bool|string $option
+ *     Peut avoir 3 valeurs :
+ *
+ *     - false : ne pas l'exécuter mais la retourner,
+ *     - true : exécuter la requête
+ *     - 'continue' : ne pas échouer en cas de serveur sql indisponible
+ * @return bool|string
+ *     - True si la table existe,
+ *     - False sinon,
+ *     - Texte de la requête si demandé,
+ *     - False en cas d'erreur.
+ **/
+function sql_table_exists(string $table, bool $table_spip = true, $serveur = '', $option = true) {
+	$f = sql_serveur('table_exists', $serveur, $option === 'continue' or $option === false);
+	if (!is_string($f) or !$f) {
+		return false;
+	}
+
+	// la globale n'est remplie qu'apres l'appel de sql_serveur.
+	if ($table_spip) {
+		$connexion = $GLOBALS['connexions'][$serveur ? strtolower($serveur) : 0];
+		$prefixe = $connexion['prefixe'];
+		$vraie_table = prefixer_table_spip($table, $prefixe);
+	} else {
+		$vraie_table = $table;
+	}
+
+	return $f($vraie_table, $serveur, $option !== false);
+}
+
+
 /**
  * Crée une table dans la base de données
  *
@@ -1306,7 +1349,7 @@ function sql_create(
  * @api
  * @param string $nom Nom de la base (sans l'extension de fichier si gestionnaire SQLite)
  * @param string $serveur Nom de la connexion
- * @param bool $option
+ * @param bool|string $option
  *     Peut avoir 3 valeurs :
  *
  *     - false : ne pas l'exécuter mais la retourner,
@@ -1412,7 +1455,7 @@ function sql_multi($sel, $lang, $serveur = '', $option = true) {
  *      False si le serveur est indisponible
  */
 function sql_error($serveur = '') {
-	$f = sql_serveur('error', $serveur, 'continue');
+	$f = sql_serveur('error', $serveur, true);
 	if (!is_string($f) or !$f) {
 		return false;
 	}
@@ -1431,7 +1474,7 @@ function sql_error($serveur = '') {
  *      False si le serveur est indisponible
  */
 function sql_errno($serveur = '') {
-	$f = sql_serveur('errno', $serveur, 'continue');
+	$f = sql_serveur('errno', $serveur, true);
 	if (!is_string($f) or !$f) {
 		return false;
 	}
@@ -1445,16 +1488,16 @@ function sql_errno($serveur = '') {
  * @api
  * @param string $q Texte de la requête
  * @param string $serveur Nom de la connexion
- * @param bool $option
+ * @param bool|string $option
  *     Peut avoir 3 valeurs :
  *
  *     - false : ne pas l'exécuter mais la retourner,
  *     - true : exécuter la requête
  *     - 'continue' : ne pas échouer en cas de serveur sql indisponible
- * @return array           Tableau de l'explication
+ * @return array|false   Tableau de l'explication
  */
 function sql_explain($q, $serveur = '', $option = true) {
-	$f = sql_serveur('explain', $serveur, 'continue');
+	$f = sql_serveur('explain', $serveur, true);
 	if (!is_string($f) or !$f) {
 		return false;
 	}
@@ -1499,7 +1542,7 @@ function sql_optimize($table, $serveur = '', $option = true) {
  * @api
  * @param string $table Nom de la table SQL
  * @param string $serveur Nom de la connexion
- * @param bool $option
+ * @param bool|string $option
  *     Peut avoir 3 valeurs :
  *
  *     - false : ne pas l'exécuter mais la retourner,
@@ -1532,7 +1575,7 @@ function sql_repair($table, $serveur = '', $option = true) {
  * @api
  * @param string $ins Requête
  * @param string $serveur Nom de la connexion
- * @param bool $option
+ * @param bool|string $option
  *     Peut avoir 3 valeurs :
  *
  *     - false : ne pas l'exécuter mais la retourner,
@@ -1585,8 +1628,8 @@ function sql_query($ins, $serveur = '', $option = true) {
  *    Tableau de classement (Order By)
  * @param string $limit
  *    Critere de limite (Limit)
- * @param array $having
- *    Tableau des des post-conditions a remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *    Le serveur sollicite (pour retrouver la connexion)
  * @param bool|string $option
@@ -1653,8 +1696,8 @@ function sql_fetsel(
  *    Tableau de classement (Order By)
  * @param string $limit
  *    Critere de limite (Limit)
- * @param array $having
- *    Tableau des des post-conditions a remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *    Le serveur sollicite (pour retrouver la connexion)
  * @param bool|string $option
@@ -1723,8 +1766,8 @@ function sql_allfetsel(
  *     Tableau de classement (Order By)
  * @param string $limit
  *     Critère de limite (Limit)
- * @param array $having
- *     Tableau des des post-conditions à remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *     Le serveur sollicité (pour retrouver la connexion)
  * @param bool|string $option
@@ -1822,7 +1865,7 @@ function sql_version($serveur = '', $option = true) {
  *    Le serveur SQL prefere t'il des transactions pour les insertions multiples ?
  **/
 function sql_preferer_transaction($serveur = '', $option = true) {
-	$f = sql_serveur('preferer_transaction', $serveur, 'continue');
+	$f = sql_serveur('preferer_transaction', $serveur, true);
 	if (!is_string($f) or !$f) {
 		return false;
 	}
@@ -1856,7 +1899,7 @@ function sql_preferer_transaction($serveur = '', $option = true) {
  *      false en cas d'erreur
  **/
 function sql_demarrer_transaction($serveur = '', $option = true) {
-	$f = sql_serveur('demarrer_transaction', $serveur, 'continue');
+	$f = sql_serveur('demarrer_transaction', $serveur, true);
 	if (!is_string($f) or !$f) {
 		return false;
 	}
@@ -1890,7 +1933,7 @@ function sql_demarrer_transaction($serveur = '', $option = true) {
  *      false en cas d'erreur
  **/
 function sql_terminer_transaction($serveur = '', $option = true) {
-	$f = sql_serveur('terminer_transaction', $serveur, 'continue');
+	$f = sql_serveur('terminer_transaction', $serveur, true);
 	if (!is_string($f) or !$f) {
 		return false;
 	}
@@ -2020,9 +2063,9 @@ function sql_date_proche($champ, $interval, $unite, $serveur = '', $option = tru
  * @param string $type
  *   type du champ pour le sql_quote
  * @param bool|string $option
- *   Peut avoir 2 valeurs :
+ *   Peut avoir 3 valeurs :
  *
- *   - continue -> ne pas echouer en cas de serveur sql indisponible
+ *   - 'continue' -> ne pas echouer en cas de serveur sql indisponible
  *   - true ou false -> retourne l'expression
  * @return string
  *     Expression de requête SQL
@@ -2034,9 +2077,7 @@ function sql_in_quote($champ, $valeurs, $not = '', $serveur = '', $type = '', $o
 	}
 
 	// sql_quote produit une chaine dans tous les cas
-	$valeurs = array_filter($valeurs, function ($v) {
- return !is_array($v);
-	});
+	$valeurs = array_filter($valeurs, fn($v) => !is_array($v));
 	$valeurs = array_unique($valeurs);
 	$valeurs = $quote($valeurs, $type);
 
@@ -2111,8 +2152,8 @@ function sql_in($champ, $valeurs, $not = '', $serveur = '', $option = true) {
  *     Tableau de classement (Order By)
  * @param string $limit
  *     Critere de limite (Limit)
- * @param array $having
- *     Tableau des des post-conditions a remplir (Having)
+ * @param string|array $having
+ *     Tableau ou chaine des des post-conditions à remplir (Having)
  * @param string $serveur
  *     Nom du connecteur
  * @return string
@@ -2148,7 +2189,7 @@ function sql_in_select(
  *
  * @see sql_seek()
  *
- * @param resource $res
+ * @param Object $res
  *    Ressource issue d'une selection sql_select
  * @param int $pos
  *   position courante
