@@ -43,7 +43,7 @@ require_once _ROOT_RESTREINT . 'base/objets.php';
 function spip_connect($serveur = '', $version = '') {
 
 	$serveur = !is_string($serveur) ? '' : strtolower($serveur);
-	$index = $serveur ? $serveur : 0;
+	$index = $serveur ?: 0;
 	if (!$version) {
 		$version = $GLOBALS['spip_sql_version'];
 	}
@@ -60,8 +60,7 @@ function spip_connect($serveur = '', $version = '') {
 			? '' // nom de serveur mal ecrit
 			: ($serveur ?
 				(_DIR_CONNECT . $serveur . '.php') // serveur externe
-				: (_FILE_CONNECT ? _FILE_CONNECT // serveur principal ok
-					: ($install ? _FILE_CONNECT_TMP // init du serveur principal
+				: (_FILE_CONNECT ?: ($install ? _FILE_CONNECT_TMP // init du serveur principal
 						: ''))); // installation pas faite
 
 		unset($GLOBALS['db_ok']);
@@ -116,7 +115,7 @@ function spip_connect($serveur = '', $version = '') {
 		return $GLOBALS['connexions'][$index];
 	}
 
-	$GLOBALS['connexions'][$index]['spip_connect_version'] = isset($GLOBALS['spip_connect_version']) ? $GLOBALS['spip_connect_version'] : 0;
+	$GLOBALS['connexions'][$index]['spip_connect_version'] = $GLOBALS['spip_connect_version'] ?? 0;
 
 	// initialisation de l'alphabet utilise dans les connexions SQL
 	// si l'installation l'a determine.
@@ -165,7 +164,7 @@ function spip_connect($serveur = '', $version = '') {
 function spip_sql_erreur($serveur = '') {
 	$connexion = spip_connect($serveur);
 	$e = sql_errno($serveur);
-	$t = (isset($connexion['type']) ? $connexion['type'] : 'sql');
+	$t = ($connexion['type'] ?? 'sql');
 	$m = "Erreur $e de $t: " . sql_error($serveur) . "\nin " . sql_error_backtrace() . "\n" . trim($connexion['last']);
 	$f = $t . $serveur;
 	spip_log($m, $f . '.' . _LOG_ERREUR);
@@ -191,7 +190,11 @@ function spip_sql_erreur($serveur = '') {
  **/
 function spip_connect_sql($version, $ins = '', $serveur = '', $continue = false) {
 	$desc = spip_connect($serveur, $version);
-	if (function_exists($f = @$desc[$version][$ins])) {
+	if (
+		$desc
+		and $f = ($desc[$version][$ins] ?? '')
+		and function_exists($f)
+	) {
 		return $f;
 	}
 	if ($continue) {
@@ -225,7 +228,7 @@ function spip_connect_sql($version, $ins = '', $serveur = '', $continue = false)
  * @param string $prefixe Préfixe des tables SPIP
  * @param string $auth Type d'authentification (cas si 'ldap')
  * @param string $charset Charset de la connexion SQL (optionnel)
- * @return array          Description de la connexion
+ * @return array|null Description de la connexion
  */
 function spip_connect_db(
 	$host,
@@ -262,18 +265,17 @@ function spip_connect_db(
 	) {
 		spip_log("Echec : $f recent. Pas de tentative de connexion", _LOG_HS);
 
-		return;
+		return null;
 	}
 
 	if (!$prefixe) {
-		$prefixe = isset($GLOBALS['table_prefix'])
-			? $GLOBALS['table_prefix'] : $db;
+		$prefixe = $GLOBALS['table_prefix'] ?? $db;
 	}
 	$h = charger_fonction($type, 'req', true);
 	if (!$h) {
 		spip_log("les requetes $type ne sont pas fournies", _LOG_HS);
 
-		return;
+		return null;
 	}
 	if ($g = $h($host, $port, $login, $pass, $db, $prefixe)) {
 		if (!is_array($auth)) {
@@ -292,6 +294,7 @@ function spip_connect_db(
 		@touch($f);
 		spip_log("Echec connexion serveur $type : host[$host] port[$port] login[$login] base[$db]", $type . '.' . _LOG_HS);
 	}
+	return null;
 }
 
 
@@ -378,13 +381,20 @@ function spip_connect_ldap($serveur = '') {
  * @note
  *   L'usage comme échappement SQL est déprécié, à remplacer par sql_quote().
  *
- * @param num|string|array $a Valeur à échapper
+ * @param int|float|string|array $a Valeur à échapper
  * @return string Valeur échappée.
  **/
-function _q($a) {
-	return (is_numeric($a)) ? strval($a) :
-		(!is_array($a) ? ("'" . addslashes($a) . "'")
-			: join(',', array_map('_q', $a)));
+function _q($a): string {
+	if (is_numeric($a)) {
+		return strval($a);
+	} elseif (is_array($a)) {
+		return join(',', array_map('_q', $a));
+	} elseif (is_scalar($a)) {
+		return ("'" . addslashes($a) . "'");
+	} elseif ($a === null) {
+		return "''";
+	}
+	throw new \RuntimeException('Can’t use _q with ' . gettype($a));
 }
 
 /**
@@ -399,14 +409,14 @@ function _q($a) {
  * @param string $query
  * @return array
  */
-function query_echappe_textes($query, $uniqid=null) {
+function query_echappe_textes($query, $uniqid = null) {
 	static $codeEchappements = null;
-	if (is_null($codeEchappements)) {
+	if (is_null($codeEchappements) or $uniqid) {
 		if (is_null($uniqid)) {
 			$uniqid = uniqid();
 		}
 		$uniqid = substr(md5($uniqid), 0, 4);
-		$codeEchappements = ["\\\\" => "\x1@#{$uniqid}#@\x1", "\\'" => "\x2@#{$uniqid}#@\x2", '\\"' => "\x3@#{$uniqid}#@\x3"];
+		$codeEchappements = ['\\\\' => "\x1@#{$uniqid}#@\x1", "\\'" => "\x2@#{$uniqid}#@\x2", '\\"' => "\x3@#{$uniqid}#@\x3", '%' => "\x4@#{$uniqid}#@\x4"];
 	}
 	if ($query === null) {
 		return $codeEchappements;
@@ -415,45 +425,54 @@ function query_echappe_textes($query, $uniqid=null) {
 	// si la query contient deja des codes d'echappement on va s'emmeler les pinceaux et donc on ne touche a rien
 	// ce n'est pas un cas legitime
 	foreach ($codeEchappements as $codeEchappement) {
-		if (strpos($query, $codeEchappement) !== false) {
+		if (strpos($query, (string) $codeEchappement) !== false) {
 			return [$query, []];
 		}
 	}
 
 	$query_echappees = str_replace(array_keys($codeEchappements), array_values($codeEchappements), $query);
 	if (preg_match_all("/('[^']*')|(\"[^\"]*\")/S", $query_echappees, $textes)) {
-		$textes = reset($textes); // indice 0 du match
-		switch (count($textes)) {
-			case 0:
-				$replace = [];
-				break;
-			case 1:
-				$replace = ['%1$s'];
-				break;
-			case 2:
-				$replace = ['%1$s', '%2$s'];
-				break;
-			case 3:
-				$replace = ['%1$s', '%2$s', '%3$s'];
-				break;
-			case 4:
-				$replace = ['%1$s', '%2$s', '%3$s', '%4$s'];
-				break;
-			case 5:
-				$replace = ['%1$s', '%2$s', '%3$s', '%4$s', '%5$s'];
-				break;
-			default:
-				$replace = range(1, count($textes));
-				$replace = '%' . implode('$s,%', $replace) . '$s';
-				$replace = explode(',', $replace);
-				break;
+		$textes = reset($textes);
+
+		$parts = [];
+		$currentpos = 0;
+		$k = 0;
+		while (count($textes)) {
+			$part = array_shift($textes);
+			$nextpos = strpos($query_echappees, $part, $currentpos);
+			// si besoin recoller ensemble les doubles '' de sqlite (echappement des ')
+			while (count($textes) and substr($part, -1) === "'") {
+				$next = reset($textes);
+				if (
+					strpos($next, "'") === 0
+					and strpos($query_echappees, $part . $next, $currentpos) === $nextpos
+				) {
+					$part .= array_shift($textes);
+				}
+				else {
+					break;
+				}
+			}
+			$k++;
+			$parts[$k] = [
+				'texte' => $part,
+				'position' => $nextpos,
+				'placeholder' => '%' . $k . '$s',
+			];
+			$currentpos = $nextpos + strlen($part);
 		}
-		$query_echappees = str_replace($textes, $replace, $query_echappees);
+
+		// et on replace les parts une par une en commencant par la fin
+		while ($k > 0) {
+			$query_echappees = substr_replace($query_echappees, $parts[$k]['placeholder'], $parts[$k]['position'], strlen($parts[$k]['texte']));
+			$k--;
+		}
+		$textes = array_column($parts, 'texte');
 	} else {
 		$textes = [];
 	}
 
-	// si il reste des quotes simples ou doubles, c'est qu'on s'est emmelles les pinceaux
+	// si il reste des quotes simples ou doubles, c'est qu'on s'est emmelle les pinceaux
 	// dans le doute on ne touche a rien
 	if (strpbrk($query_echappees, "'\"") !== false) {
 		return [$query, []];
@@ -476,7 +495,9 @@ function query_reinjecte_textes($query, $textes) {
 	// recuperer les codes echappements
 	$codeEchappements = query_echappe_textes(null);
 
-	$query = sprintf($query, ...$textes);
+	if (!empty($textes)) {
+		$query = sprintf($query, ...$textes);
+	}
 
 	$query = str_replace(array_values($codeEchappements), array_keys($codeEchappements), $query);
 
