@@ -135,9 +135,9 @@ function maj_base($version_cible = 0, $redirect = '', $debut_page = true) {
 		return true;
 	}
 
-	$cible = ($version_cible ? $version_cible : $GLOBALS['spip_version_base']);
+	$cible = ($version_cible ?: $GLOBALS['spip_version_base']);
 
-	if ($version_installee < 2021010100) {
+	if ($version_installee < 2021_01_01_00) {
 		include_spip('maj/legacy/v21');
 		include_spip('maj/legacy/v30');
 		include_spip('maj/legacy/v31');
@@ -151,7 +151,7 @@ function maj_base($version_cible = 0, $redirect = '', $debut_page = true) {
 	$res = maj_while($version_installee, $cible, $GLOBALS['maj'], 'version_installee', 'meta', $redirect, $debut_page);
 	if ($res) {
 		if (!is_array($res)) {
-			spip_log("Pb d'acces SQL a la mise a jour", 'maj.' . _LOG_INFO_ERREUR);
+			spip_log("Pb d'acces SQL a la mise a jour", 'maj.' . _LOG_ERREUR);
 		} else {
 			echo _T('avis_operation_echec') . ' ' . join(' ', $res);
 			echo install_fin_html();
@@ -241,7 +241,7 @@ function maj_plugin($nom_meta_base_version, $version_cible, $maj, $table_meta =
 		$res = maj_while($current_version, $version_cible, $maj, $nom_meta_base_version, $table_meta, $redirect);
 		if ($res) {
 			if (!is_array($res)) {
-				spip_log("Pb d'acces SQL a la mise a jour", 'maj.' . _LOG_INFO_ERREUR);
+				spip_log("Pb d'acces SQL a la mise a jour", 'maj.' . _LOG_ERREUR);
 			} else {
 				echo '<p>' . _T('avis_operation_echec') . ' ' . join(' ', $res) . '</p>';
 			}
@@ -291,7 +291,9 @@ function maj_debut_page($installee, $meta, $table) {
 		return;
 	}
 	include_spip('inc/minipres');
-	@ini_set('zlib.output_compression', '0'); // pour permettre l'affichage au fur et a mesure
+	if (function_exists('ini_set')) {
+		@ini_set('zlib.output_compression', '0'); // pour permettre l'affichage au fur et a mesure
+	}
 	$timeout = _UPGRADE_TIME_OUT * 2;
 	$titre = _T('titre_page_upgrade');
 	$balise_img = charger_filtre('balise_img');
@@ -453,7 +455,7 @@ function serie_alter($serie, $q = [], $meta = '', $table = 'meta', $redirect = '
 					ecrire_meta($meta2, $i + 1, 'non', $table);
 				}
 				echo (_IS_CLI ? '.' : " <span title='$i'>.</span>");
-				call_user_func_array($f, $r);
+				$f(...$r);
 				// si temps imparti depasse, on relance sans ecrire en meta
 				// car on est peut etre sorti sur timeout si c'est une fonction longue
 				if (time() >= _TIME_OUT) {
