@@ -443,7 +443,7 @@ function css_regroup_atimport($nom_tmp, $nom) {
 	} // rien a faire
 
 	preg_match_all(',@import ([^;]*);,UmsS', $contenu, $matches, PREG_SET_ORDER);
-	$imports = array_map('reset', $matches);
+	$imports = array_column($matches, 0);
 	$contenu = str_replace($imports, '', $contenu);
 	$contenu = implode("\n", $imports) . "\n" . $contenu;
 	ecrire_fichier_calcule_si_modifie($nom, $contenu);
