@@ -96,7 +96,7 @@ function minifier_css($contenu, $options = '') {
 		$contenu = preg_replace('/font-weight:normal/ims', 'font-weight:400', $contenu);
 
 		// si elle est 0, enlever la partie entière des unites decimales
-		$contenu = preg_replace("/\b0+\.(\d+em)/ims", '.$1', $contenu);
+		$contenu = preg_replace("/\b0+\.(\d+(r?em|vh|vw))/ims", '.$1', $contenu);
 		// supprimer les declarations vides
 		$contenu = preg_replace(',(^|})([^{}]*){},Ums', '$1', $contenu);
 		// supprimer l'unité quand la valeur est zéro (sauf pour % car casse les @keyframes cf https://core.spip.net/issues/3128 et sauf pour les chaînes en base64 cf https://core.spip.net/issues/3991)
@@ -144,11 +144,11 @@ function minifier_css($contenu, $options = '') {
 		$contenu = preg_replace($colors['source'], $colors['replace'], $contenu);
 
 		// raccourcir les padding qui le peuvent (sur 3 ou 2 valeurs)
-		$contenu = preg_replace(",padding:([^\s;}]+)\s([^\s;}]+)\s([^\s;}]+)\s(\\2),ims", 'padding:$1 $2 $3', $contenu);
+		$contenu = preg_replace(",padding:([^\s;}]+)\s([^\s;}]+)\s([^\s;}]+)\s(\\2)([;}!]),ims", 'padding:$1 $2 $3$5', $contenu);
 		$contenu = preg_replace(",padding:([^\s;}]+)\s([^\s;}]+)\s(\\1)([;}!]),ims", 'padding:$1 $2$4', $contenu);
 
 		// raccourcir les margin qui le peuvent (sur 3 ou 2 valeurs)
-		$contenu = preg_replace(",margin:([^\s;}]+)\s([^\s;}]+)\s([^\s;}]+)\s(\\2),ims", 'margin:$1 $2 $3', $contenu);
+		$contenu = preg_replace(",margin:([^\s;}]+)\s([^\s;}]+)\s([^\s;}]+)\s(\\2)([;}!]),ims", 'margin:$1 $2 $3$5', $contenu);
 		$contenu = preg_replace(",margin:([^\s;}]+)\s([^\s;}]+)\s(\\1)([;}!]),ims", 'margin:$1 $2$4', $contenu);
 
 		$contenu = trim($contenu);
@@ -166,8 +166,9 @@ function minifier_css($contenu, $options = '') {
 		}
 		// @media eventuel pour prefixe toutes les css
 		// et regrouper plusieurs css entre elles
+		// on ignore media=all par comodite, comme pour le compresseur simple (c'est le par defaut)
 		$media = '';
-		if (isset($options['media'])) {
+		if (!empty($options['media']) and $options['media'] !== 'all') {
 			$media = '@media ' . $options['media'] . ' ';
 		}
 
