@@ -1,14 +1,14 @@
-﻿<?php
+<?php
 
-/***************************************************************************\
+/***************************************************************************
  *  SPIP, Système de publication pour l'internet                           *
  *                                                                         *
- *  Copyright © avec tendresse depuis 2001                                 *
+ *  Copyright (c) avec tendresse depuis 2001                               *
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
  *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
-\***************************************************************************/
+ ***************************************************************************/
 
 /**
  * Déclarations d'autorisations
