@@ -5,7 +5,7 @@
  * ------------------
  */
 
-define('_ECRAN_SECURITE', '1.4.2'); // 2022-07-12
+define('_ECRAN_SECURITE', '1.5.0'); // 2023-02-27
 
 /*
  * Documentation : https://www.spip.net/fr_article4200.html
@@ -649,6 +649,22 @@ if (
 	$ecran_securite_raison = "malformed _oups argument";
 }
 
+if (
+	isset($_REQUEST['formulaire_action_args'])
+) {
+	foreach ($_REQUEST as $k => $v) {
+		if (is_string($v)
+		  and strpos($v, ':') !== false
+		  and strpos($v, '"') !==false
+		  and preg_match(',[bidsaO]:,', $v)
+		  and @unserialize($v)) {
+			$_REQUEST[$k] = htmlentities($v);
+			if (isset($_POST[$k])) $_POST[$k] = $_REQUEST[$k];
+			if (isset($_GET[$k])) $_GET[$k] = $_REQUEST[$k];
+		}
+	}
+}
+
 
 /*
  * S'il y a une raison de mourir, mourons
@@ -704,7 +720,7 @@ if (
 			and $load = floatval($load))
 	)
 	and $load > _ECRAN_SECURITE_LOAD // eviter l'evaluation suivante si de toute facon le load est inferieur a la limite
-	and rand(0, $load * $load) > _ECRAN_SECURITE_LOAD * _ECRAN_SECURITE_LOAD
+	and rand(0, (int) ($load * $load)) > _ECRAN_SECURITE_LOAD * _ECRAN_SECURITE_LOAD
 ) {
 	//https://webmasters.stackexchange.com/questions/65674/should-i-return-a-429-or-503-status-code-to-a-bot
 	header("HTTP/1.0 429 Too Many Requests");
