@@ -32,6 +32,8 @@ function multiple_de_trois($val) {
  * @return array
  */
 function _couleur_rgb2hsv($R, $G, $B) {
+	$H = null;
+	$ret = [];
 	$var_R = ($R / 255);                    //Where RGB values = 0 Ã· 255
 	$var_G = ($G / 255);
 	$var_B = ($B / 255);
@@ -93,6 +95,7 @@ function _couleur_rgb2hsv($R, $G, $B) {
  */
 function _couleur_hsv2rgb($H, $S, $V) {
 
+	$ret = [];
 	if ($S == 0) {                       //HSV values = 0 Ã· 1
 	$R = $V * 255;
 		$G = $V * 255;
@@ -194,7 +197,6 @@ function _couleur_hsl2rgb($H, $S, $L) {
 // Par defaut, la couleur choisie se trouve un peu au-dessus du centre de l'image.
 // On peut forcer un point en fixant $x et $y, entre 0 et 20.
 // si on passe 'moyenne' pour x alors une couleur moyenne est calculee sur les 20x20px
-// https://code.spip.net/@image_couleur_extraire
 
 function _image_couleur_extraire($img, $x = 10, $y = 6) {
 	static $couleur_extraite = [];
