@@ -24,7 +24,7 @@ function formulaires_oubli_charger_dist() {
 // https://code.spip.net/@message_oubli
 function message_oubli($email, $param) {
 	$r = formulaires_oubli_mail($email);
-	
+
 	if (is_array($r) and $r[1] and $r[1]['statut'] !== '5poubelle' and $r[1]['pass'] !== '') {
 		include_spip('inc/texte'); # pour corriger_typo
 
@@ -108,7 +108,7 @@ function formulaires_oubli_mail($email) {
 
 		return array(
 			$declaration,
-			sql_fetsel('id_auteur,statut,pass', 'spip_auteurs', 'email =' . sql_quote($declaration['mail']))
+			sql_fetsel('id_auteur,statut,pass', 'spip_auteurs', "login<>'' AND email =" . sql_quote($declaration['mail']))
 		);
 	}
 }
