@@ -41,7 +41,7 @@ function formulaires_recherche_ecrire_charger_dist($action = '', $class = '') {
 
 	return
 		[
-			'action' => ($action ? $action : generer_url_ecrire('recherche')),
+			'action' => ($action ?: generer_url_ecrire('recherche')),
 			# action specifique, ne passe pas par Verifier, ni Traiter
 			'recherche' => _request('recherche'),
 			'lang' => $lang,
