@@ -78,7 +78,7 @@ function formulaires_forum_prive_charger_dist($objet, $id_objet, $id_forum, $for
 		'table' => $table,
 		'texte' => '',
 		'config' => $config,
-		'titre' => isset($titre) ? $titre : '',
+		'titre' => $titre ?? '',
 		'_hidden' => $script_hidden, # pour les variables hidden
 		'url_site' => '',
 		'forcer_previsu' => $forcer_previsu,
@@ -207,7 +207,7 @@ function formulaires_forum_prive_traiter_dist($objet, $id_objet, $id_forum, $for
 			} else {
 				$thread = sql_fetsel('id_thread', 'spip_forum', 'id_forum=' . $id_reponse);
 				spip_log('id_thread=' . $thread['id_thread'], 'forum');
-				$retour = generer_url_entite($thread['id_thread'], 'forum');
+				$retour = generer_objet_url($thread['id_thread'], 'forum');
 			}
 		}
 
