@@ -28,7 +28,7 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  */
 function genie_mise_a_jour_dist($t) {
 	include_spip('inc/meta');
-	$maj = info_maj('spip', 'SPIP', $GLOBALS['spip_version_branche']);
+	$maj = info_maj($GLOBALS['spip_version_branche']);
 	ecrire_meta('info_maj_spip', $maj ? ($GLOBALS['spip_version_branche'] . "|$maj") : '', 'non');
 
 	mise_a_jour_ecran_securite();
@@ -41,8 +41,8 @@ function genie_mise_a_jour_dist($t) {
 // TODO : fournir une URL sur spip.net pour maitriser la diffusion d'une nouvelle version de l'ecran via l'update auto
 // ex : https://www.spip.net/auto-update/ecran_securite.php
 define('_URL_ECRAN_SECURITE', 'https://git.spip.net/spip-contrib-outils/securite/raw/branch/master/ecran_securite.php');
-define('_VERSIONS_SERVEUR', 'https://files.spip.net/');
-define('_VERSIONS_LISTE', 'archives.xml');
+define('_VERSIONS_SERVEUR', 'https://www.spip.net/spip_loader.api');
+define('_VERSIONS_LISTE', 'spip_versions_list.json');
 
 /**
  * Mise a jour automatisee de l'ecran de securite
@@ -99,8 +99,6 @@ function mise_a_jour_ecran_securite() {
  *
  * Repérer aussi si cette version est une version majeure de SPIP.
  *
- * @param string $dir
- * @param string $file
  * @param string $version
  *      La version reçue ici est sous la forme x.y.z
  *      On la transforme par la suite pour avoir des integer ($maj, $min, $rev)
@@ -108,94 +106,119 @@ function mise_a_jour_ecran_securite() {
  *
  * @return string
  */
-function info_maj($dir, $file, $version) {
+function info_maj(string $version): string {
 	include_spip('inc/plugin');
 
-	[$maj, $min, $rev] = preg_split('/\D+/', $version);
-
-	$nom = _DIR_CACHE_XML . _VERSIONS_LISTE;
-	$page = !file_exists($nom) ? '' : file_get_contents($nom);
-	$page = info_maj_cache($nom, $dir, $page);
-
-	// reperer toutes les versions de numero majeur superieur ou egal
-	// (a revoir quand on arrivera a SPIP V10 ...)
-	$p = substr('0123456789', intval($maj));
-	$p = ',/' . $file . '\D+([' . $p . ']+)\D+(\d+)(\D+(\d+))?.*?[.]zip",i';
-	preg_match_all($p, $page, $m, PREG_SET_ORDER);
-	$page = $page_majeure = '';
-
-	// branche en cours d'utilisation
-	$branche = implode('.', array_slice(explode('.', $version, 3), 0, 2));
-
-	foreach ($m as $v) {
-		$v = array_pad($v, 5, 0);
-		[, $maj2, $min2, , $rev2] = $v;
-		$branche_maj = $maj2 . '.' . $min2;
-		$version_maj = $maj2 . '.' . $min2 . '.' . $rev2;
-		// d'abord les mises à jour de la même branche
-		if (
-			(spip_version_compare($version, $version_maj, '<'))
-			and (spip_version_compare($page, $version_maj, '<'))
-			and spip_version_compare($branche, $branche_maj, '=')
-		) {
-			$page = $version_maj;
-		}
-		// puis les mises à jours majeures
-		if (
-			(spip_version_compare($version, $version_maj, '<'))
-			and (spip_version_compare($page, $version_maj, '<'))
-			and spip_version_compare($branche, $branche_maj, '<')
-		) {
-			$page_majeure = $version_maj;
-		}
-	}
-	if (!$page and !$page_majeure) {
+	// API V1
+	$contenu = info_maj_cache();
+	if (!$contenu) {
 		return '';
 	}
 
-	$message = $page ? _T('nouvelle_version_spip', ['version' => $page]) . ($page_majeure ? ' | ' : '') : '';
-	$message .= $page_majeure ? _T('nouvelle_version_spip_majeure', ['version' => $page_majeure]) : '';
+	$maj = info_maj_versions($version, array_keys($contenu['versions'] ?? []));
+	if (!$maj['mineure'] and !$maj['majeure']) {
+		return '';
+	}
 
-	return "<a class='info_maj_spip' href='https://www.spip.net/fr_update' title='$page'>" . $message . '</a>';
+	$message = [];
+	if ($maj['mineure']) {
+		$message[] = _T('nouvelle_version_spip', ['version' => $maj['mineure']]);
+	}
+	if ($maj['majeure']) {
+		$message[] = _T('nouvelle_version_spip_majeure', ['version' => $maj['majeure']]);
+	}
+
+	return '<a class="info_maj_spip" href="https://www.spip.net/fr_update" title="' . $maj['mineure'] . '">' . implode(' | ', $message) . '</a>';
 }
 
 /**
- * Vérifie que la liste $page des versions dans le fichier $nom est à jour.
+ * Retourne (et sauvegarde) la liste des mises à jour de SPIP
  *
- * Ce fichier rajoute dans ce fichier l'aléa éphémère courant;
- * on teste la nouveauté par If-Modified-Since,
+ * On teste la nouveauté par If-Modified-Since,
  * et seulement quand celui-ci a changé pour limiter les accès HTTP.
  * Si le fichier n'a pas été modifié, on garde l'ancienne version.
  *
  * @see info_maj()
- *
- * @param string $nom
- *     Nom du fichier contenant les infos de mise à jour.
- * @param string $dir
- * @param string $page
- * @return string
- *     Contenu du fichier de cache de l'info de maj de SPIP.
+ * @internal
+ * @return array|null Contenu du fichier de cache de l'info de maj de SPIP.
  */
-function info_maj_cache($nom, $dir, $page = '') {
-	include_spip('inc/acces');
-	$alea_ephemere = charger_aleas();
-	$re = '<archives id="a' . $alea_ephemere . '">';
-	if (preg_match("/$re/", $page)) {
-		return $page;
+function info_maj_cache(): ?array {
+	$contenu = '';
+	$options = [];
+	$nom = _DIR_CACHE . _VERSIONS_LISTE;
+	if (file_exists($nom)) {
+		$contenu = file_get_contents($nom);
+		$options['if_modified_since'] = filemtime($nom);
 	}
-
-	$url = _VERSIONS_SERVEUR . $dir . '/' . _VERSIONS_LISTE;
-	$a = file_exists($nom) ? filemtime($nom) : '';
 	include_spip('inc/distant');
-	$res = recuperer_url_cache($url, ['if_modified_since' => $a]);
-	// Si rien de neuf (ou inaccessible), garder l'ancienne
-	if ($res) {
-		$page = $res['page'] ?: $page;
-	}
-	// Placer l'indicateur de fraicheur
-	$page = preg_replace('/^<archives.*?>/', $re, $page);
-	sous_repertoire(_DIR_CACHE_XML);
-	ecrire_fichier($nom, $page);
+	$res = recuperer_url_cache(_VERSIONS_SERVEUR, $options);
 
-	return $page;
+	// Si rien de neuf (ou inaccessible), garder l'ancienne
+	if ($res and $res['page']) {
+		$contenu = $res['page'];
+		ecrire_fichier($nom, $contenu);
+	}
+
+	if (!$contenu) {
+		return null;
+	}
+
+	try {
+		$json = json_decode($contenu, true, 512, JSON_THROW_ON_ERROR);
+	} catch (JsonException $e) {
+		spip_log('Failed to parse Json data : ' . $e->getMessage(), 'verifie_maj');
+		return null;
+	}
+
+	return $json;
+}
+
+/**
+ * Vérifier si on doit proposer une mise à jour pour les versions dont on dispose
+ *
+ * - version mineure, quelque soit notre état actuel
+ * - version majeure, seulement si la majeure est stable (pas alpha, beta, rc, ...)
+ *
+ * @internal
+ * @param string $version Notre version
+ * @param string[] $versions Les dernières versions distantes
+ * @return array<string, string> Version mineure supérieure, version majeure supérieure
+ */
+function info_maj_versions(string $version, array $versions): array {
+	$maj = ['mineure' => '', 'majeure' => ''];
+	if (!$version) {
+		return $maj;
+	}
+
+	// pas de version dev
+	$versions = array_diff($versions, ['dev']);
+
+	// branche en cours d'utilisation
+	$branche = implode('.', array_slice(explode('.', $version, 3), 0, 2));
+
+	foreach ($versions as $v) {
+		[$maj2, $min2, $rev2] = explode('.', $v);
+		$branche_maj = $maj2 . '.' . $min2;
+		$version_maj = $maj2 . '.' . $min2 . '.' . $rev2;
+		$is_version_stable = is_numeric($rev2);
+		// d'abord les mises à jour de la même branche (version mineure)
+		if (
+			spip_version_compare($version, $version_maj, '<')
+			and spip_version_compare($maj['mineure'], $version_maj, '<')
+			and spip_version_compare($branche, $branche_maj, '=')
+		) {
+			$maj['mineure'] = $version_maj;
+		}
+		// puis les mises à jours majeures
+		if (
+			$is_version_stable
+			and spip_version_compare($version, $version_maj, '<')
+			and spip_version_compare($maj['majeure'], $version_maj, '<')
+			and spip_version_compare($branche, $branche_maj, '<')
+		) {
+			$maj['majeure'] = $version_maj;
+		}
+	}
+
+	return $maj;
 }
