@@ -64,6 +64,31 @@ function inc_auth_dist() {
 	return $n ?: 1;
 }
 
+/**
+ * Vérifier qu'un mot de passe saisi pour confirmer une action est bien celui de l'auteur connecté
+ * @param string $password
+ * @return bool
+ */
+function auth_controler_password_auteur_connecte(string $password): bool {
+
+	if (
+		empty($GLOBALS['visiteur_session']['id_auteur'])
+		or empty($GLOBALS['visiteur_session']['login'])
+	) {
+		return false;
+	}
+
+	$auth = auth_identifier_login($GLOBALS['visiteur_session']['login'], $password, '', true);
+	if (
+		is_array($auth)
+		and $auth['id_auteur'] == $GLOBALS['visiteur_session']['id_auteur']
+	) {
+		return true;
+	}
+
+	return false;
+}
+
 /**
  * fonction appliquee par ecrire/index sur le resultat de la precedente
  * en cas de refus de connexion.
@@ -477,11 +502,11 @@ function auth_informer_login($login, $serveur = '') {
  * @param string $serveur
  * @return mixed
  */
-function auth_identifier_login($login, $password, $serveur = '') {
+function auth_identifier_login($login, $password, $serveur = '', bool $phpauth = false) {
 	$erreur = '';
 	foreach ($GLOBALS['liste_des_authentifications'] as $methode) {
 		if ($auth = charger_fonction($methode, 'auth', true)) {
-			$auteur = $auth($login, $password, $serveur);
+			$auteur = $auth($login, $password, $serveur, $phpauth);
 			if (is_array($auteur) and count($auteur)) {
 				spip_log("connexion de $login par methode $methode");
 				$auteur['auth'] = $methode;
