@@ -29,12 +29,13 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  * @param string $fichier
  * @return string
  */
-function set_spip_doc($fichier) {
-	if (strpos($fichier, _DIR_IMG) === 0) {
+function set_spip_doc(?string $fichier): string {
+	if ($fichier and strpos($fichier, (string) _DIR_IMG) === 0) {
 		return substr($fichier, strlen(_DIR_IMG));
 	} else {
-		return $fichier;
-	} // ex: fichier distant
+		// ex: fichier distant
+		return $fichier ?? '';
+	}
 }
 
 /**
@@ -45,7 +46,11 @@ function set_spip_doc($fichier) {
  * @param string $fichier
  * @return bool|string
  */
-function get_spip_doc($fichier) {
+function get_spip_doc(?string $fichier) {
+	if ($fichier === null) {
+		return false;
+	}
+
 	// fichier distant
 	if (tester_url_absolue($fichier)) {
 		return $fichier;
@@ -56,11 +61,9 @@ function get_spip_doc($fichier) {
 		return false;
 	}
 
-	$fichier = (
-		strncmp($fichier, _DIR_IMG, strlen(_DIR_IMG)) != 0
-	)
-		? _DIR_IMG . $fichier
-		: $fichier;
+	if (strncmp($fichier, _DIR_IMG, strlen(_DIR_IMG)) !== 0) {
+		$fichier = _DIR_IMG . $fichier;
+	}
 
 	// fichier normal
 	return $fichier;
@@ -138,27 +141,29 @@ function effacer_repertoire_temporaire($nom) {
 function copier_document($ext, $orig, $source, $subdir = null) {
 
 	$orig = preg_replace(',\.\.+,', '.', $orig); // pas de .. dans le nom du doc
-	$dir = creer_repertoire_documents($subdir ? $subdir : $ext);
+	$dir = creer_repertoire_documents($subdir ?: $ext);
 
 	$dest = preg_replace('/<[^>]*>/', '', basename($orig));
-	$dest = preg_replace('/\.([^.]+)$/','', $dest);
+	$dest = preg_replace('/\.([^.]+)$/', '', $dest);
 	$dest = translitteration($dest);
-	$dest = preg_replace('/[^.=\w-]+/','_', $dest);
+	$dest = preg_replace('/[^.=\w-]+/', '_', $dest);
 
 	// ne pas accepter de noms de la forme -r90.jpg qui sont reserves
 	// pour les images transformees par rotation (action/documenter)
 	$dest = preg_replace(',-r(90|180|270)$,', '', $dest);
 
-	while (preg_match(",\.(\w+)$,", $dest, $m)) {
-		if (!function_exists('verifier_upload_autorise')
-		  or !$r = verifier_upload_autorise($dest)
-		  or $r['autozip']) {
+	while (preg_match(',\.(\w+)$,', $dest, $m)) {
+		if (
+			!function_exists('verifier_upload_autorise')
+			or !$r = verifier_upload_autorise($dest)
+			or $r['autozip']
+		) {
 			$dest = substr($dest, 0, -strlen($m[0])) . '_' . $m[1];
 			break;
 		}
 		else {
 			$dest = substr($dest, 0, -strlen($m[0]));
-			$ext = $m[1] . "." . $ext;
+			$ext = $m[1] . '.' . $ext;
 		}
 	}
 
@@ -370,4 +375,4 @@ function corriger_extension($ext) {
 	}
 
 	return $ext;
-}
\ No newline at end of file
+}
