@@ -112,11 +112,15 @@ function chercher_rubrique(
 
 	$confirm = '';
 	if ($objet == 'rubrique') {
+		// FIXME: Migration plus adapté vers le plugin Brèves ?
 		// si c'est une rubrique-secteur contenant des breves, demander la
 		// confirmation du deplacement
-		$contient_breves = sql_countsel('spip_breves', 'id_rubrique=' . intval($id_objet));
-
-		if ($contient_breves > 0) {
+		if (
+			sql_table_exists('spip_breves')
+			and ($contient_breves = sql_countsel('spip_breves', 'id_rubrique=' . intval($id_objet)))
+			and ($contient_breves > 0)
+		) {
+			// FIXME: utiliser singulier_ou_pluriel, migrer dans plugin Brèves
 			$scb = ($contient_breves > 1 ? 's' : '');
 			$scb = _T(
 				'avis_deplacement_rubrique',
@@ -591,17 +595,15 @@ function lister_objets_lies($objet_source, $objet, $id_objet, $objet_lien) {
 		return [];
 	}
 	$r = reset($res);
+	$colonne_id = ($objet_source == $objet_lien ? id_table_objet($objet_source) : 'id_objet');
 	if (isset($r['rang_lien'])) {
-		$l = array_column($res, 'rang_lien', $objet_source);
+		$l = array_column($res, 'rang_lien', $colonne_id);
 		asort($l);
 		$l = array_keys($l);
 	} else {
 		// Si les liens qu'on cherche sont ceux de la table de lien, l'info est dans la clé de l'objet
 		// Sinon c'est dans "id_objet"
-		$l = array_column(
-			$res,
-			$objet_source == $objet_lien ? id_table_objet($objet_source) : 'id_objet'
-		);
+		$l = array_column($res, $colonne_id);
 	}
 	return $l;
 }
