@@ -26,8 +26,8 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 // duree maximale du cache. Le double pour l'antidater
 define('_META_CACHE_TIME', 1 << 24);
 
-// https://code.spip.net/@inc_meta_dist
 function inc_meta_dist($table = 'meta') {
+	$new = null;
 	// Lire les meta, en cache si present, valide et lisible
 	// en cas d'install ne pas faire confiance au meta_cache eventuel
 	$cache = cache_meta($table);
@@ -56,7 +56,7 @@ function inc_meta_dist($table = 'meta') {
 	if (
 		(test_espace_prive() || isset($_GET['renouvelle_alea']))
 		and $GLOBALS[$table]
-		and (time() > _RENOUVELLE_ALEA + (isset($GLOBALS['meta']['alea_ephemere_date']) ? $GLOBALS['meta']['alea_ephemere_date'] : 0))
+		and (time() > _RENOUVELLE_ALEA + ($GLOBALS['meta']['alea_ephemere_date'] ?? 0))
 	) {
 		// si on n'a pas l'acces en ecriture sur le cache,
 		// ne pas renouveller l'alea sinon le cache devient faux
@@ -77,7 +77,6 @@ function inc_meta_dist($table = 'meta') {
 // fonctions aussi appelees a l'install ==> spip_query en premiere requete
 // pour eviter l'erreur fatale (serveur non encore configure)
 
-// https://code.spip.net/@lire_metas
 function lire_metas($table = 'meta') {
 
 	if ($result = spip_query("SELECT nom,valeur FROM spip_$table")) {
@@ -112,7 +111,7 @@ function lire_metas($table = 'meta') {
 		}
 	}
 
-	return isset($GLOBALS[$table]) ? $GLOBALS[$table] : null;
+	return $GLOBALS[$table] ?? null;
 }
 
 
@@ -128,7 +127,7 @@ function lire_metas($table = 'meta') {
 function touch_meta($antidate = false, $table = 'meta') {
 	$file = cache_meta($table);
 	if (!$antidate or !@touch($file, $antidate)) {
-		$r = isset($GLOBALS[$table]) ? $GLOBALS[$table] : [];
+		$r = $GLOBALS[$table] ?? [];
 		if ($table == 'meta') {
 			unset($r['alea_ephemere']);
 			unset($r['alea_ephemere_ancien']);
@@ -185,8 +184,9 @@ function effacer_meta($nom, $table = 'meta') {
  *     Nom de la meta
  * @param string $valeur
  *     Valeur à enregistrer
- * @param bool|null $importable
+ * @param string|null $importable
  *     Cette meta s'importe-elle avec une restauration de sauvegarde ?
+ *     'oui' ou 'non'
  * @param string $table
  *     Table SQL d'enregistrement de la meta.
  **/
