@@ -32,7 +32,7 @@ include_spip('inc/texte'); //inclue inc/lang et inc/filtres
  * @uses utiliser_langue_visiteur()
  * @uses http_no_cache()
  * @uses html_lang_attributes()
- * @uses compacte() si le plugin compresseur est présent
+ * @uses minifier() si le plugin compresseur est présent
  * @uses url_absolue_css()
  *
  * @param string $titre
@@ -66,8 +66,8 @@ function install_debut_html($titre = 'AUTO', $onLoad = '', $all_inline = false)
 		// inliner les CSS (optimisation de la page minipres qui passe en un seul hit a la demande)
 		foreach ($files as $name) {
 			$file = direction_css(find_in_theme($name));
-			if (function_exists('compacte')) {
-				$file = compacte($file);
+			if (function_exists('minifier')) {
+				$file = minifier($file);
 			} else {
 				$file = url_absolue_css($file); // precaution
 			}
@@ -184,8 +184,8 @@ function minipres($titre = '', $corps = '', $options = []) {
 			? _T('avis_espace_interdit')
 			: $titre . '&nbsp;: ' . _T('info_acces_interdit');
 
-		$statut = isset($GLOBALS['visiteur_session']['statut']) ? $GLOBALS['visiteur_session']['statut'] : '';
-		$nom = isset($GLOBALS['visiteur_session']['nom']) ? $GLOBALS['visiteur_session']['nom'] : '';
+		$statut = $GLOBALS['visiteur_session']['statut'] ?? '';
+		$nom = $GLOBALS['visiteur_session']['nom'] ?? '';
 
 		if ($statut != '0minirezo') {
 			$titre = _T('info_acces_interdit');
@@ -206,12 +206,23 @@ function minipres($titre = '', $corps = '', $options = []) {
 
 	if (!_AJAX) {
 		if (isset($options['status'])) {
-			http_status($options['status']);
+			http_response_code($options['status']);
 		}
 
-		return install_debut_html($titre, $options['onload'], $options['all_inline'])
-		. $corps
-		. install_fin_html();
+		$html = install_debut_html($titre, $options['onload'], $options['all_inline'])
+				. $corps
+				. install_fin_html();
+
+		if (
+			$GLOBALS['profondeur_url'] >= (_DIR_RESTREINT ? 1 : 2)
+			and empty($options['all_inline'])
+		) {
+			define('_SET_HTML_BASE', true);
+			include_spip('public/assembler');
+			$GLOBALS['html'] = true;
+			page_base_href($html);
+		}
+		return $html;
 	} else {
 		include_spip('inc/headers');
 		include_spip('inc/actions');
