@@ -30,7 +30,6 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  * Cette fonction est appelée par le pipeline header_prive
  *
  * @see f_jQuery()
- * @link https://code.spip.net/@f_jQuery
  *
  * @param string $texte Contenu qui sera inséré dans le head HTML
  * @return string          Contenu complété des scripts javascripts, dont jQuery
@@ -46,7 +45,6 @@ function f_jQuery_prive($texte) {
 			'prive/javascript/jquery.placeholder-label.js',
 			'prive/javascript/ajaxCallback.js',
 			'prive/javascript/js.cookie.js',
-			'prive/javascript/jquery.cookie.js',
 			'prive/javascript/spip_barre.js',
 		]
 	);
@@ -59,7 +57,7 @@ function f_jQuery_prive($texte) {
 	// inserer avant le premier script externe ou a la fin
 	if (
 		preg_match(',<script[^><]*src=,', $texte, $match)
-		and $p = strpos($texte, $match[0])
+		and $p = strpos($texte, (string) $match[0])
 	) {
 		$texte = substr_replace($texte, $x, $p, 0);
 	} else {
@@ -104,7 +102,6 @@ function affichage_final_prive_title_auto($texte) {
 
 
 // Fonction standard pour le pipeline 'boite_infos'
-// https://code.spip.net/@f_boite_infos
 function f_boite_infos($flux) {
 	$args = $flux['args'];
 	$type = $args['type'];
@@ -136,7 +133,7 @@ function f_boite_infos($flux) {
 function f_afficher_blocs_ecrire($flux) {
 	static $o = [];
 	if (is_string($fond = $flux['args']['fond'])) {
-		$exec = isset($flux['args']['contexte']['exec']) ? $flux['args']['contexte']['exec'] : _request('exec');
+		$exec = $flux['args']['contexte']['exec'] ?? _request('exec');
 		if (!isset($o[$exec])) {
 			$o[$exec] = trouver_objet_exec($exec);
 		}
@@ -144,7 +141,7 @@ function f_afficher_blocs_ecrire($flux) {
 		if ($exec == 'infos_perso') {
 			$flux['args']['contexte']['id_auteur'] = $GLOBALS['visiteur_session']['id_auteur'];
 		}
-		$typepage = (isset($flux['args']['contexte']['type-page']) ? $flux['args']['contexte']['type-page'] : $exec);
+		$typepage = ($flux['args']['contexte']['type-page'] ?? $exec);
 		if ($fond == "prive/squelettes/navigation/$typepage") {
 			$flux['data']['texte'] = pipeline(
 				'affiche_gauche',
@@ -317,17 +314,17 @@ function f_queue_affiche_milieu($flux) {
  * renvoie false si pas d'objet en cours, ou un tableau associatif
  * contenant les informations table_objet_sql,table,type,id_table_objet,edition
  *
- * @param string $exec
+ * @param ?string $exec
  *   nom de la page testee
  * @return array|bool
  */
-function trouver_objet_exec($exec) {
+function trouver_objet_exec(?string $exec) {
 	static $objet_exec = [];
 	if (!$exec) {
 		return false;
 	}
 	// cas particulier
-	if ($exec == 'infos_perso') {
+	if ($exec === 'infos_perso') {
 		$exec = 'auteur';
 		set_request('id_auteur', $GLOBALS['visiteur_session']['id_auteur']);
 	}
@@ -335,7 +332,7 @@ function trouver_objet_exec($exec) {
 		$objet_exec[$exec] = false;
 		$infos = lister_tables_objets_sql();
 		foreach ($infos as $t => $info) {
-			if ($exec == $info['url_edit'] and $info['editable']) {
+			if ($exec === $info['url_edit'] and $info['editable']) {
 				return $objet_exec[$exec] = [
 					'edition' => $exec == $info['url_voir'] ? '' : true,
 					'table_objet_sql' => $t,
@@ -344,7 +341,7 @@ function trouver_objet_exec($exec) {
 					'id_table_objet' => id_table_objet($info['type'])
 				];
 			}
-			if ($exec == $info['url_voir']) {
+			if ($exec === $info['url_voir']) {
 				return $objet_exec[$exec] = [
 					'edition' => false,
 					'table_objet_sql' => $t,
