@@ -239,7 +239,7 @@ function queue_start_job($row) {
 
 	// deserialiser les arguments
 	$args = unserialize($row['args']);
-	if ($args === false) {
+	if (!is_array($args)) {
 		spip_log('arguments job errones ' . var_export($row, true), 'queue');
 		$args = [];
 	}
@@ -263,55 +263,7 @@ function queue_start_job($row) {
 	}
 
 	spip_log('queue [' . $row['id_job'] . "]: $fonction() start", 'queue');
-	switch (count($args)) {
-		case 0:
-			$res = $fonction();
-			break;
-		case 1:
-			$res = $fonction($args[0]);
-			break;
-		case 2:
-			$res = $fonction($args[0], $args[1]);
-			break;
-		case 3:
-			$res = $fonction($args[0], $args[1], $args[2]);
-			break;
-		case 4:
-			$res = $fonction($args[0], $args[1], $args[2], $args[3]);
-			break;
-		case 5:
-			$res = $fonction($args[0], $args[1], $args[2], $args[3], $args[4]);
-			break;
-		case 6:
-			$res = $fonction($args[0], $args[1], $args[2], $args[3], $args[4], $args[5]);
-			break;
-		case 7:
-			$res = $fonction($args[0], $args[1], $args[2], $args[3], $args[4], $args[5], $args[6]);
-			break;
-		case 8:
-			$res = $fonction($args[0], $args[1], $args[2], $args[3], $args[4], $args[5], $args[6], $args[7]);
-			break;
-		case 9:
-			$res = $fonction($args[0], $args[1], $args[2], $args[3], $args[4], $args[5], $args[6], $args[7], $args[8]);
-			break;
-		case 10:
-			$res = $fonction(
-				$args[0],
-				$args[1],
-				$args[2],
-				$args[3],
-				$args[4],
-				$args[5],
-				$args[6],
-				$args[7],
-				$args[8],
-				$args[9]
-			);
-			break;
-		default:
-			# plus lent mais completement generique
-			$res = call_user_func_array($fonction, $args);
-	}
+	$res = $fonction(...$args);
 	spip_log('queue [' . $row['id_job'] . "]: $fonction() end", 'queue');
 
 	return $res;
@@ -694,7 +646,7 @@ function queue_lancer_url_http_async($url_cron) {
 		}
 		$fp = @fsockopen(
 			$scheme . $parts['host'],
-			isset($parts['port']) ? $parts['port'] : $port,
+			$parts['port'] ?? $port,
 			$errno,
 			$errstr,
 			1
