@@ -62,17 +62,17 @@ function urls_decoder_url($url, $fond = '', $contexte = [], $assembler = false)
 	// les anciennes fonctions modifient directement les globales
 	// on les sauve avant l'appel, et on les retablit apres !
 	$save = [
-		isset($GLOBALS['fond']) ? $GLOBALS['fond'] : null,
-		isset($GLOBALS['contexte']) ? $GLOBALS['contexte'] : null,
-		isset($_SERVER['REDIRECT_url_propre']) ? $_SERVER['REDIRECT_url_propre'] : null,
-		isset($_ENV['url_propre']) ? $_ENV['url_propre'] : null,
+		$GLOBALS['fond'] ?? null,
+		$GLOBALS['contexte'] ?? null,
+		$_SERVER['REDIRECT_url_propre'] ?? null,
+		$_ENV['url_propre'] ?? null,
 		$GLOBALS['profondeur_url']
 	];
 
 	if (is_null($current_base)) {
 		include_spip('inc/filtres_mini');
 		// le decodage des urls se fait toujours par rapport au site public
-		$current_base = url_absolue(_DIR_RACINE ? _DIR_RACINE : './');
+		$current_base = url_absolue(_DIR_RACINE ?: './');
 	}
 	if (strncmp($url, $current_base, strlen($current_base)) == 0) {
 		$url = substr($url, strlen($current_base));
@@ -109,15 +109,13 @@ function urls_decoder_url($url, $fond = '', $contexte = [], $assembler = false)
 	}
 
 	$url_redirect = '';
-	$renommer = generer_url_entite('', '', '', '', true);
-	if (!$renommer and !function_exists('recuperer_parametres_url')) {
-		$renommer = charger_fonction('page', 'urls');
-	} // fallback pour decoder l'url
-	if ($renommer) {
-		$a = $renommer($url, $fond, $contexte);
+	$decoder = charger_fonction_url('decoder');
+	if ($decoder) {
+		$a = $decoder($url, $fond, $contexte);
 		if (is_array($a)) {
-			list($ncontexte, $type, $url_redirect, $nfond) = array_pad($a, 4, null);
-			if ($url_redirect == $url) {
+			[$ncontexte, $type, $url_redirect, $nfond] = array_pad($a, 4, null);
+			$url_redirect ??= '';
+			if ($url_redirect === $url) {
 				$url_redirect = '';
 			} // securite pour eviter une redirection infinie
 			if ($assembler and strlen($url_redirect)) {
@@ -145,17 +143,10 @@ function urls_decoder_url($url, $fond = '', $contexte = [], $assembler = false)
 				$contexte['type-page'] = $type;
 			}
 		}
-	} // compatibilite <= 1.9.2
-	elseif (function_exists('recuperer_parametres_url')) {
-		$GLOBALS['fond'] = $fond;
-		$GLOBALS['contexte'] = $contexte;
-		recuperer_parametres_url($fond, nettoyer_uri());
-		// fond est en principe modifiee directement
-		$contexte = $GLOBALS['contexte'];
 	}
 
 	// retablir les globales
-	list($GLOBALS['fond'], $GLOBALS['contexte'], $_SERVER['REDIRECT_url_propre'], $_ENV['url_propre'], $GLOBALS['profondeur_url']) = $save;
+	[$GLOBALS['fond'], $GLOBALS['contexte'], $_SERVER['REDIRECT_url_propre'], $_ENV['url_propre'], $GLOBALS['profondeur_url']] = $save;
 
 	// vider les globales url propres qui ne doivent plus etre utilisees en cas
 	// d'inversion url => objet
@@ -168,6 +159,78 @@ function urls_decoder_url($url, $fond = '', $contexte = [], $assembler = false)
 	return [$fond, $contexte, $url_redirect];
 }
 
+/**
+ * Le bloc qui suit sert a faciliter les transitions depuis
+ * le mode 'urls-propres' vers les modes 'urls-standard' et 'url-html'
+ *
+ * @param string $url_propre
+ * @param string $entite
+ * @param array $contexte
+ * @return array|false|string
+ */
+function urls_transition_retrouver_anciennes_url_propres(string $url_propre, string $entite, array $contexte = []): array {
+	if ($url_propre) {
+		if ($GLOBALS['profondeur_url'] <= 0) {
+			$urls_anciennes = charger_fonction_url('decoder', 'propres');
+		} else {
+			$urls_anciennes = charger_fonction_url('decoder', 'arbo');
+		}
+
+		if ($urls_anciennes) {
+			$urls_anciennes = $urls_anciennes($url_propre, $entite, $contexte);
+		}
+		return $urls_anciennes ?: [];
+	}
+
+	return [];
+}
+
+/**
+ * Le bloc qui suit sert a faciliter les transitions depuis
+ * le mode 'urls-html/standard' vers les modes 'urls propres|arbos'
+ *
+ * @param string $url_propre
+ * @param string $entite
+ * @param array $contexte
+ * @return array|false|string
+ */
+function urls_transition_retrouver_anciennes_url_html(string $url, string $entite, array $contexte = []): array {
+	// Migration depuis anciennes URLs ?
+	// traiter les injections domain.tld/spip.php/n/importe/quoi/rubrique23
+	if (
+		$url
+		and $GLOBALS['profondeur_url'] <= 0
+	) {
+		$r = nettoyer_url_page($url, $contexte);
+		if ($r) {
+			[$contexte, $type, , , $suite] = $r;
+			$_id = id_table_objet($type);
+			$id_objet = $contexte[$_id];
+			$url_propre = generer_objet_url($id_objet, $type);
+			if (
+				strlen($url_propre)
+				and !strstr($url, (string) $url_propre)
+				and (
+					objet_test_si_publie($type, $id_objet)
+					or (defined('_VAR_PREVIEW') and _VAR_PREVIEW and autoriser('voir', $type, $id_objet))
+				)
+			) {
+				[, $hash] = array_pad(explode('#', $url_propre), 2, '');
+				$args = [];
+				foreach (array_filter(explode('&', $suite)) as $fragment) {
+					if ($fragment != "$_id=$id_objet") {
+						$args[] = $fragment;
+					}
+				}
+				$url_redirect = generer_objet_url($id_objet, $type, join('&', array_filter($args)), $hash);
+
+				return [$contexte, $type, $url_redirect, $type];
+			}
+		}
+	}
+	/* Fin compatibilite anciennes urls */
+	return [];
+}
 
 /**
  * Lister les objets pris en compte dans les URLs
@@ -238,22 +301,24 @@ function nettoyer_url_page($url, $contexte = []) {
  * L'URL est calculée en fonction de son état publié ou non,
  * calculé à partir de la déclaration de statut.
  *
+ * @param int|string|null $id Identifiant de l'objet
  * @param string $objet Type d'objet
- * @param int $id Identifiant de l'objet
  * @param string $args
  * @param string $ancre
  * @param bool|null $public
  * @param string $connect
  * @return string
- *
  */
-function generer_url_ecrire_objet($objet, $id, $args = '', $ancre = '', $public = null, $connect = '') {
+function generer_objet_url_ecrire($id, string $objet, string $args = '', string $ancre = '', ?bool $public = null, string $connect = ''): string {
 	static $furls = [];
+	$id = intval($id);
 	if (!isset($furls[$objet])) {
 		if (
-			function_exists($f = 'generer_url_ecrire_' . $objet)
+			function_exists($f = 'generer_' . $objet . '_url_ecrire')
 			// ou definie par un plugin
 			or $f = charger_fonction($f, 'urls', true)
+			// deprecated
+			or function_exists($f = 'generer_url_ecrire_' . $objet) or $f = charger_fonction($f, 'urls', true)
 		) {
 			$furls[$objet] = $f;
 		} else {
@@ -269,7 +334,7 @@ function generer_url_ecrire_objet($objet, $id, $args = '', $ancre = '', $public
 		$public = objet_test_si_publie($objet, $id, $connect);
 	}
 	if ($public or $connect) {
-		return generer_url_entite_absolue($id, $objet, $args, $ancre, $connect);
+		return generer_objet_url_absolue($id, $objet, $args, $ancre, $public, '', $connect);
 	}
 	$a = id_table_objet($objet) . '=' . intval($id);
 	if (!function_exists('objet_info')) {
@@ -278,3 +343,11 @@ function generer_url_ecrire_objet($objet, $id, $args = '', $ancre = '', $public
 
 	return generer_url_ecrire(objet_info($objet, 'url_voir'), $a . ($args ? "&$args" : '')) . ($ancre ? "#$ancre" : '');
 }
+
+/**
+ * @deprecated 4.1
+ * @see generer_objet_url_ecrire
+ */
+function generer_url_ecrire_objet($objet, $id, $args = '', $ancre = '', $public = null, string $connect = '') {
+	return generer_objet_url_ecrire($id, $objet, $args, $ancre, $public, $connect);
+}
