@@ -40,8 +40,15 @@ function install_etape_ldap2_dist() {
 			$tls = true;
 		}
 	}
+	else {
+		$tls_ldap == 'non';
+	}
+
+	// Verifions que l'adresse demandee est valide
+	$adresse_ldap = filter_var($adresse_ldap, FILTER_SANITIZE_URL) ?: '';
+
 	$ldap_link = ldap_connect($adresse_ldap, $port_ldap);
-	$erreur = "ldap_connect($adresse_ldap, $port_ldap)";
+	$erreur = 'ldap_connect(' . spip_htmlspecialchars($adresse_ldap) . ', ' . spip_htmlspecialchars($port_ldap) . ')';
 
 	if ($ldap_link) {
 		if (!ldap_set_option($ldap_link, LDAP_OPT_PROTOCOL_VERSION, $protocole_ldap)) {
@@ -50,13 +57,19 @@ function install_etape_ldap2_dist() {
 		}
 		if ($tls === true) {
 			if (!ldap_start_tls($ldap_link)) {
-				$erreur = "ldap_start_tls($ldap_link) $adresse_ldap, $port_ldap";
+				$erreur = 'ldap_start_tls(' . spip_htmlspecialchars($ldap_link)
+					. ' ' . spip_htmlspecialchars($adresse_ldap)
+					. ', ' . spip_htmlspecialchars($port_ldap) . ')';
 				$ldap_link = false;
 			}
 		}
 		if ($ldap_link) {
 			$ldap_link = ldap_bind($ldap_link, $login_ldap, $pass_ldap);
-			$erreur = "ldap_bind('$ldap_link', '$login_ldap', '$pass_ldap'): $adresse_ldap, $port_ldap";
+			$erreur = "ldap_bind('" . spip_htmlspecialchars($ldap_link)
+				. "', '" . spip_htmlspecialchars($login_ldap)
+				. "', '" . spip_htmlspecialchars($pass_ldap)
+				. "'): " . spip_htmlspecialchars($adresse_ldap)
+				. ', ' . spip_htmlspecialchars($port_ldap);
 		}
 	}
 
@@ -67,12 +80,12 @@ function install_etape_ldap2_dist() {
 		),  _T('info_connexion_ldap_ok');
 		echo generer_form_ecrire('install', (
 			"\n<input type='hidden' name='etape' value='ldap3' />"
-			. "\n<input type='hidden' name='adresse_ldap' value=\"$adresse_ldap\" />"
-			. "\n<input type='hidden' name='port_ldap' value=\"$port_ldap\" />"
-			. "\n<input type='hidden' name='login_ldap' value=\"$login_ldap\" />"
-			. "\n<input type='hidden' name='pass_ldap' value=\"$pass_ldap\" />"
-			. "\n<input type='hidden' name='protocole_ldap' value=\"$protocole_ldap\" />"
-			. "\n<input type='hidden' name='tls_ldap' value=\"$tls_ldap\" />"
+			. "\n<input type='hidden' name='adresse_ldap' value=\"" . spip_htmlspecialchars($adresse_ldap) . '" />'
+			. "\n<input type='hidden' name='port_ldap' value=\"" . spip_htmlspecialchars($port_ldap) . '" />'
+			. "\n<input type='hidden' name='login_ldap' value=\"" . spip_htmlspecialchars($login_ldap) . '" />'
+			. "\n<input type='hidden' name='pass_ldap' value=\"" . spip_htmlspecialchars($pass_ldap) . '" />'
+			. "\n<input type='hidden' name='protocole_ldap' value=\"" . spip_htmlspecialchars($protocole_ldap) . '" />'
+			. "\n<input type='hidden' name='tls_ldap' value=\"" . spip_htmlspecialchars($tls_ldap) . '" />'
 			. bouton_suivant()));
 	} else {
 		echo info_etape(_T('titre_connexion_ldap')), info_progression_etape(1, 'etape_ldap', 'install/', true),
