@@ -14,8 +14,8 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
-// https://code.spip.net/@install_etape_ldap3_dist
 function install_etape_ldap3_dist() {
+	$info = [];
 	$adresse_ldap = _request('adresse_ldap');
 	$login_ldap = _request('login_ldap');
 	$pass_ldap = _request('pass_ldap');
