@@ -27,11 +27,10 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  * Permet d'itérer sur des données en base de données
  */
 class IterateurSQL implements Iterator {
-
 	/**
-	 * ressource sql
+	 * Ressource sql
 	 *
-	 * @var resource|bool
+	 * @var Object|bool
 	 */
 	protected $sqlresult = false;
 
@@ -105,10 +104,10 @@ class IterateurSQL implements Iterator {
 	 *
 	 * @return bool
 	 */
-	public function rewind() {
-		return ($this->pos > 0)
-			? $this->seek(0)
-			: true;
+	public function rewind(): void {
+		if ($this->pos > 0) {
+			$this->seek(0);
+		}
 	}
 
 	/**
@@ -116,7 +115,7 @@ class IterateurSQL implements Iterator {
 	 *
 	 * @return bool
 	 */
-	public function valid() {
+	public function valid(): bool {
 		if ($this->err) {
 			return false;
 		}
@@ -132,10 +131,12 @@ class IterateurSQL implements Iterator {
 	 *
 	 * @return array
 	 */
+	#[\ReturnTypeWillChange]
 	public function current() {
 		return $this->row;
 	}
 
+	#[\ReturnTypeWillChange]
 	public function key() {
 		return $this->pos;
 	}
@@ -172,7 +173,7 @@ class IterateurSQL implements Iterator {
 	 *
 	 * @return void
 	 */
-	public function next() {
+	public function next(): void {
 		$this->row = sql_fetch($this->sqlresult, $this->command['connect']);
 		$this->pos++;
 		$this->firstseek |= true;
