@@ -319,8 +319,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_exportation_base' => 'نقل قاعدة البيانات الى @archive@',
 	'info_facilite_suivi_activite' => 'لتسهيل متابعة أنشطة تحرير
 الموقع، يرسل SPIP عبر البريد الى لائحة احد المحررين البريدية مثلاً،
-الإعلان عن
-طلبات النشر وتصديق المقالات.',
+الإعلان عن طلبات النشر وتصديق المقالات. يمكن ادخال عنوان او اكثر تفصل بينها فواصل.',
 	'info_fichiers_authent' => 'ملف التحقق «.htpasswd»',
 	'info_forums_abo_invites' => 'يحتوي موقعك على منتديات بالاشتراك. يشترك الزوار اذاً من الموقع العمومي.',
 	'info_gauche_admin_tech' => '<b>لا يحق إلا لمسؤولي الموقع الوصول الى هذه الصفحة.</b><p> إنها توفر الوصول الى وظائف
