@@ -213,7 +213,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
   СПИП изпраща по електронна поща съобщение с молбите за публикуване и одобрените статии до
   някой пощенски списък
   на редактори, например.
-',
+', # MODIF
 	'info_fichiers_authent' => 'Файл за удостоверяване автентичността: .htpasswd',
 	'info_forums_abo_invites' => 'Сайтът Ви съдържа форуми посредством предварителен абонамент; посетителите могат да се регистират за тях през публичния сайт.',
 	'info_gauche_admin_tech' => '<b>Само администратори имат достъп до тази страница.</b><p> Тя осигурява достъп до различни
