@@ -191,7 +191,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_1' => 'mi yí tɛnɔtɛ é bɔɖéwú ɔ jí.',
 	'info_etape_suivante_2' => 'mi yí tɛnɔtɛ é bɔɖéwú ɔ jí.',
 	'info_exportation_base' => 'bíbɛ xóxókplé sɔ yì',
-	'info_facilite_suivi_activite' => 'bíbɛ xóxókplé sɔ yì',
+	'info_facilite_suivi_activite' => 'bíbɛ xóxókplé sɔ yì', # MODIF
 	'info_fichiers_authent' => 'xó xókplé ',
 	'info_forums_abo_invites' => 'jōnɔ lɛ ní ná nyíkɔ.',
 	'info_gauche_admin_tech' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
