@@ -225,7 +225,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_1' => 'អ្នកអាចទៅ ជំហានបន្ទាប់។',
 	'info_etape_suivante_2' => 'អ្នកអាចទៅ ជំហានបន្ទាប់។',
 	'info_exportation_base' => 'នាំចេញ មូលដ្ឋានទិន្នន័យ ទៅ @archive@',
-	'info_facilite_suivi_activite' => 'សំរាប់សំរួល ការតាមដាន សកម្មភាពបោះផ្សាយ នៃសៃថ៍, SPIP អាចជូនដំណឹង តាមមែវល៍, ជាឧទាហរ ទៅបញ្ជីផ្ញើមែវល៍ របស់ពួកស្មេរ, ជំនូនដំណឹង នៃសំណើ បោះផ្សាយនានា និងភាពសុពលភាព នៃអត្ថបទនានា។',
+	'info_facilite_suivi_activite' => 'សំរាប់សំរួល ការតាមដាន សកម្មភាពបោះផ្សាយ នៃសៃថ៍, SPIP អាចជូនដំណឹង តាមមែវល៍, ជាឧទាហរ ទៅបញ្ជីផ្ញើមែវល៍ របស់ពួកស្មេរ, ជំនូនដំណឹង នៃសំណើ បោះផ្សាយនានា និងភាពសុពលភាព នៃអត្ថបទនានា។', # MODIF
 	'info_fichiers_authent' => 'ហ្វា​ល​យថាភាព \\".htpasswd\\"',
 	'info_forums_abo_invites' => 'វ៉ែបសៃថ៍ របស់អ្នក រួមមាន ទីប្រជុំមតិ តាមរយះការជាវ ; ចឹង ពួកទស្សនាករ អាចចុះឈ្មោះ ចូលរួម ទីប្រជុំមតិទាំងនេះ លើសៃថ៍សាធារណះ។',
 	'info_gauche_admin_tech' => '<b>ត្រឹម ពួកអ្នកទទួលខុសត្រូវសៃថ៍ អាចចូលទៅ ទំព័រនេះ។</b><p> វាអនុញ្ញាត អោយចូលទៅ មុខងារថែទាំបច្ចេកទេស ដទៃ។ មួយចំនួននៃមុខងារ ផ្តល់ដំណើរ សំគាល់ជាក់លាក់, តំរូវអោយមាន FTP សំរាប់ចូលទៅ វ៉ែបសៃថ៍។</p>', # MODIF
