@@ -284,7 +284,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_2' => 'Dir kënnt bei de nächste Schrëtt weidergoen.',
 	'info_exceptions_proxy' => 'Ausnam fir de Proxy',
 	'info_exportation_base' => 'Export vun der Datebank op @archive@',
-	'info_facilite_suivi_activite' => 'Fir déi editorial Aktivitéiten ze verfollegen, ka SPIP d’Demande fir Artikelen ze verëffentlechen oder d’Bestätegungen un eng Mailingslëscht vun de Redakteren schécken.',
+	'info_facilite_suivi_activite' => 'Fir déi editorial Aktivitéiten ze verfollegen, ka SPIP d’Demande fir Artikelen ze verëffentlechen oder d’Bestätegungen un eng Mailingslëscht vun de Redakteren schécken.', # MODIF
 	'info_fichiers_authent' => 'Authentifikatiouns-Fichieren ".htpasswd"',
 	'info_forums_abo_invites' => 'Äre Site huet Forume wou een sech umelle muss; d’Visiteuren ginn also agelueden sech ze enregistréieren.',
 	'info_gauche_admin_tech' => '<b>Dës Säit ass fir déi Responsabel vum Site reservéiert.</b><p>Si erlaabt technesch Maintenance-Aarbechten. Fir verschidde vun deene Prozeduren muss een sech iwwer FTP identifizéieren kënnen.</p>',
