@@ -205,7 +205,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_1' => 'နောက်တဆင့်သို့ ရွေ့နိုင်သည်',
 	'info_etape_suivante_2' => 'နောက်တဆင့်သို့ ရွေ့နိုင်သည်',
 	'info_exportation_base' => 'အချက်အလက် သိုလှောင်မှုကို @archive@သို့ပို့ပါ',
-	'info_facilite_suivi_activite' => 'To facilitate the follow-up of the site’s editorial;  activities, SPIP can send notification by email, to an editor’s mailing list for instance, of publication requests and article validations.',
+	'info_facilite_suivi_activite' => 'To facilitate the follow-up of the site’s editorial;  activities, SPIP can send notification by email, to an editor’s mailing list for instance, of publication requests and article validations.', # MODIF
 	'info_fichiers_authent' => 'ဖိုင်\\".htpasswd\\"ကို အတည်ပြုပါ',
 	'info_forums_abo_invites' => 'သင့်ဝက်ဘ်ဆိုက် ဖိုရမ်မှာ အခမဲ့ဖြစ်သည်၊ ဝင်ရောက်ကြည့်ရှုသူများက အများသုံး ဝက်ဘ်ဆိုက်ပေါ်တွင် မှတ်ပုံတင်လိမ့်မည်',
 	'info_gauche_admin_tech' => '<b>ဝက်ဘ်ဆိုက်ကြီးကြပ်သူသာ ဤစာမျက်နှာသို့ဝင်နိုင်သည်၊</b><p> သည်ဟာက လုပ်ငန်းများစွာကို ထိန်းသိမ်းရန်အတွက် အထောက်ကူပြုသည်၊  အချို့က ဝက်ဘ်ဆိုက်ပေါ်တွင် လိုအပ်သော FTP ဆက်သွယ်မှုကို လုပ်ဆောင်စေနိုင်သည်</p>', # MODIF
