@@ -273,7 +273,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_1' => 'Nu puteţi trece la etapa următoare.',
 	'info_etape_suivante_2' => 'Puteţi trece la etapa următoare.',
 	'info_exportation_base' => 'exportul bazei de date către @archive@',
-	'info_facilite_suivi_activite' => 'Pentru a uşura urmărirea activităţii editoriale a site-ului, SPIP poate trimite prin email cererile de publicare şi de validare a articolelor. De exemplu, destinatarul poate fi o listă de distribuţie a redacţiei.',
+	'info_facilite_suivi_activite' => 'Pentru a uşura urmărirea activităţii editoriale a site-ului, SPIP poate trimite prin email cererile de publicare şi de validare a articolelor. De exemplu, destinatarul poate fi o listă de distribuţie a redacţiei.', # MODIF
 	'info_fichiers_authent' => 'Fişiere de autentificare « .htpasswd »',
 	'info_forums_abo_invites' => 'Site-ul dumneavoastră are forum-uri cu abonament ; vizitatorii sunt, aşadar, invitaţi să se înregistreze pe site-ul public.',
 	'info_gauche_admin_tech' => '<b>Această pagină este accesibilă doar responsabililor acestui site</b><br /> Ea dă acces la diverse funcţii de întreţinere tehnică. Unele dintre aceste funcţii cer un proces de autentificare specific, de exemplu să aveţi un acces FTP la site-ul Web.', # MODIF
