@@ -300,7 +300,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_exportation_base' => 'экспортировать базу данных в @archive@',
 	'info_facilite_suivi_activite' => 'Для облегчения проверки исполнения редактирования сайта;
  SPIP может рассылать уведомления по электронной почте, для редакторской почтовой рассылки например,
- прошение о публикации и утверждение статьи.',
+ прошение о публикации и утверждение статьи.', # MODIF
 	'info_fichiers_authent' => 'Файл подтверждения подлинности «.htpasswd»',
 	'info_forums_abo_invites' => 'Ваш сайт содержит форумы по подписке; посетители могут зарегистрироваться на них на основном сайте.',
 	'info_gauche_admin_tech' => '<b>Страница только для вебмастера сайта.</b> <p>Вы можете выполнять задачи по эксплуатации сайта. Часть из них может потребовать  FTP доступа к сайту.</p>',
