@@ -307,7 +307,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_2' => 'Ви можете перейти до наступного етапу.',
 	'info_exceptions_proxy' => 'Винятки для проксі',
 	'info_exportation_base' => 'експортувати базу даних в @archive@',
-	'info_facilite_suivi_activite' => 'Для полегшення моніторингу діяльності   редакційних SPIP сайт може відправити його поштою, наприклад, на  список розсилки редакторів, бізнес-додатки публікації та перевірки статей.',
+	'info_facilite_suivi_activite' => 'Для полегшення моніторингу діяльності   редакційних SPIP сайт може відправити його поштою, наприклад, на  список розсилки редакторів, бізнес-додатки публікації та перевірки статей.', # MODIF
 	'info_fichiers_authent' => 'Файл аутентифікації «.htpasswd»',
 	'info_forums_abo_invites' => 'Ваш сайт має форуми за підпискою; відвідувачі можуть зареєструватися на них на основному сайті.',
 	'info_gauche_admin_tech' => '<b>Сторінка тільки для вебмастера сайта.</b> <p>Ви можете виконувати завдання щодо експлуатації сайту. Частина з них може потребувати FTP-доступу до сайту.</p>',
