@@ -236,7 +236,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'etape' => 'Etapa',
 
 	// F
-	'fichier_introuvable' => 'Ficheiro @fichier@ não localizado',
+	'fichier_introuvable' => 'Ficheiro @fichier@ não localizado', # MODIF
 	'form_auteur_confirmation' => 'Confirme o seu endereço e-mail',
 	'form_auteur_email_modifie' => 'O seu endereço e-mail foi alterado.',
 	'form_auteur_envoi_mail_confirmation' => 'Um e-mail de confirmação foi enviado para @email@. Para validar o seu endereço de e-mail, deve abrir o endereço Web mencionado na mensagem.',
@@ -259,8 +259,7 @@ Pediu para alterar o seu endereço e-mail. Para confirmar o seu novo endereço,
 	'form_forum_message_auto' => '(esta é uma mensagem automática)',
 	'form_forum_pass' => 'palavra-passe',
 	'form_forum_probleme_mail' => 'Problema de mail :o identificador não pôde ser enviado',
-	'form_forum_voici1' => 'Estes são os seus dados para poder participar nos fóruns
- do sítio  "@nom_site_spip@" (@adresse_site@):',
+	'form_forum_voici1' => 'Aqui estão os seus dados para poder aceder ao sítio Internet do  "@nom_site_spip@" (@adresse_site@):',
 	'form_forum_voici2' => 'Eis os seus identificadores para propor artigos no
  sítio "@nom_site_spip@" (@adresse_login@):',
 	'form_indiquer_email' => 'Por favor indique o seu endereço email.',
@@ -356,7 +355,7 @@ Pediu para alterar o seu endereço e-mail. Para confirmar o seu novo endereço,
 	'info_breves_un' => '1 notícia',
 	'info_connexion_refusee' => 'Ligação recusada',
 	'info_contact_developpeur' => 'Por favor contacte um programador',
-	'info_contenance' => 'Este sítio contém :',
+	'info_contenance' => 'Este sítio contém:',
 	'info_contribution' => 'contribuições de fórum',
 	'info_copyright' => '@spip@ é um software livre distribuído @lien_gpl@.',
 	'info_copyright_doc' => 'Para mais informações, visite o sítio <a href="@spipnet@">@spipnet_affiche@</a',
