@@ -22,7 +22,12 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
-$GLOBALS['maj'][2021021800] = [
+$GLOBALS['maj'][2021_02_18_00] = [
 	['sql_alter', "TABLE spip_auteurs CHANGE imessage imessage VARCHAR(3) DEFAULT '' NOT NULL" ],
 	['sql_updateq', 'spip_auteurs', ['imessage' => 'oui'], "imessage != 'non' OR imessage IS NULL" ],
 ];
+
+$GLOBALS['maj'][2022_02_23_02] = [
+	['sql_alter', "TABLE spip_auteurs ADD backup_cles mediumtext DEFAULT '' NOT NULL" ],
+	['sql_delete', 'spip_meta', "nom='secret_du_site'" ],
+];
