@@ -50,6 +50,21 @@ function joindre_determiner_mode($mode, $id_document, $objet) {
 	return $mode;
 }
 
+/**
+ * Indique si une galerie demandée est valide
+ * 
+ * @deprecated 4.0 (SPIP 4.1) L’inclusion de galerie est déprécié (non utilisé depuis SPIP 3.0). Préferez ajax_reload() après upload.
+ * @global array medias_deprecated_liste_galeries Liste de chemins de fichiers depuis la racine SPIP autorisés.
+ * @param string|null $galerie Le fichier de galerie désiré
+ */
+function joindre_document_galerie_valide(?string $galerie): bool {
+	$galeries = [];
+	if (isset($GLOBALS['medias_deprecated_liste_galeries']) and is_array($GLOBALS['medias_deprecated_liste_galeries'])) {
+		$galeries = $GLOBALS['medias_deprecated_liste_galeries'];
+	}
+	return in_array($galerie, $galeries);
+}
+
 /**
  * Chargement du formulaire
  *
@@ -62,6 +77,7 @@ function joindre_determiner_mode($mode, $id_document, $objet) {
  * @param string $mode
  *    Le mode du document (auto,choix,document,image,vignette...), par défaut auto
  * @param string $galerie
+ *    Deprecated 4.0 (SPIP 4.1)
  *    Passer optionnellement une galerie jointe au form, plus utilise nativement,
  *    on prefere la mise a jour apres upload par ajaxReload('documents')
  * @param bool|string $proposer_media
@@ -130,7 +146,8 @@ function formulaires_joindre_document_charger_dist(
 	// On ne propose le FTP que si on a des choses a afficher
 	$valeurs['proposer_ftp'] = ($valeurs['_options_upload_ftp'] or $valeurs['_dir_upload_ftp']);
 
-	if ($galerie) {
+	/** @deprecated 4.0 (SPIP 4.1). Utiliser ajaxReload('documents') après upload */
+	if ($galerie and joindre_document_galerie_valide($galerie)) {
 		# passer optionnellement une galerie jointe au form
 		# plus utilise nativement, on prefere la mise a jour
 		# apres upload par ajaxReload('documents')
@@ -161,6 +178,7 @@ function formulaires_joindre_document_charger_dist(
  * @param string $mode
  *    Le mode du document (auto,choix,document,image,vignette...), par défaut auto
  * @param string $galerie
+ *    Deprecated 4.0 (SPIP 4.1)
  *    Passer optionnellement une galerie jointe au form, plus utilise nativement,
  *    on prefere la mise a jour apres upload par ajaxReload('documents')
  * @param bool|string $proposer_media
@@ -221,7 +239,7 @@ function formulaires_joindre_document_verifier_dist(
 					and !_request('joindre_zip')
 					and $contenu_zip = joindre_verifier_zip($files)
 				) {
-					list($fichiers, $erreurs, $tmp_zip) = $contenu_zip;
+					[$fichiers, $erreurs, $tmp_zip] = str_split($contenu_zip);
 					if ($fichiers) {
 						// on passe le md5 du fichier uniquement, on le retrouvera dans zip_to_clean de la session
 						$token_zip = md5($tmp_zip);
@@ -261,6 +279,7 @@ function formulaires_joindre_document_verifier_dist(
  * @param string $mode
  *    Le mode du document (auto,choix,document,image,vignette...), par défaut auto
  * @param string $galerie
+ *    Deprecated 4.0 (SPIP 4.1)
  *    Passer optionnellement une galerie jointe au form, plus utilise nativement,
  *    on prefere la mise a jour apres upload par ajaxReload('documents')
  * @param bool|string $proposer_media
