@@ -330,8 +330,8 @@ function medias_lister_methodes_upload($env) {
 	$methodes['distant'] = ['label_lien' => _T('medias:bouton_download_sur_le_web'),'label_bouton' => _T('bouton_choisir')];
 
 	// pipeline pour les méthodes d'upload
-	$objet = isset($env['objet']) ? $env['objet'] : '';
-	$id_objet = isset($env['id_objet']) ? $env['id_objet'] : '';
+	$objet = $env['objet'] ?? '';
+	$id_objet = $env['id_objet'] ?? '';
 
 	$methodes = pipeline(
 		'medias_methodes_upload',
@@ -412,6 +412,29 @@ function medias_trouver_modele_emb($extension, $mime_type, $modele_base = 'file'
 	return $modele_base;
 }
 
+/**
+ * Determiner si un media doit etre mis en autolien dans les modeles document
+ * Par defaut utilisé uniquement sur les media image, mais le filtre peut être surchargé pour étendre son fonctionnement
+ *
+ * @param string $media
+ * @param string $extension
+ * @param int $largeur
+ * @param int $hauteur
+ * @param int|null $id_document
+ * @return bool
+ */
+function media_determine_autolien(string $media, string $extension, int $largeur, int $hauteur, ?int $id_document=0): bool {
+	if ($media !== 'image') {
+		return false;
+	}
+	if (!defined('_IMAGE_TAILLE_MINI_AUTOLIEN')) {
+		define('_IMAGE_TAILLE_MINI_AUTOLIEN', 800);
+	}
+	if ($largeur >= _IMAGE_TAILLE_MINI_AUTOLIEN or $hauteur >=_IMAGE_TAILLE_MINI_AUTOLIEN) {
+		return true;
+	}
+	return false;
+}
 
 /**
  * Liste les classes standards des modèles de documents SPIP.
