@@ -23,7 +23,6 @@ include_spip('inc/charsets');
 include_spip('inc/texte');
 include_spip('inc/plugin'); // pour plugin_est_installe
 
-// https://code.spip.net/@ligne_plug
 function plugins_afficher_plugin_dist(
 	$url_page,
 	$plug_file,
@@ -125,15 +124,6 @@ function plugin_bouton_config($nom, $infos, $dir) {
 		);
 	}
 
-	// si le plugin CFG est la, l'essayer
-	if (defined('_DIR_PLUGIN_CFG')) {
-		if (include_spip('inc/cfg')) { // test CFG version >= 1.0.5
-		if ($cfg = icone_lien_cfg("$dir$nom", 'cfg')) {
-				return "<div class='cfg_link'>$cfg</div>";
-		}
-		}
-	}
-
 	// sinon prendre le squelette std sur le nom std
 	return recuperer_fond(
 		'prive/squelettes/inclure/cfg',
@@ -253,7 +243,6 @@ function plugin_etat_en_clair($etat) {
 	return _T('plugin_etat_' . $etat);
 }
 
-// https://code.spip.net/@plugin_propre
 function plugin_propre($texte, $module = '', $propre = 'propre') {
 	// retirer le retour a la racine du module, car le find_in_path se fait depuis la racine
 	if (_DIR_RACINE and strncmp($module, _DIR_RACINE, strlen(_DIR_RACINE)) == 0) {
@@ -271,8 +260,8 @@ function plugin_typo($texte, $module = '') {
 }
 
 
-// https://code.spip.net/@affiche_bloc_plugin
 function affiche_bloc_plugin($plug_file, $info, $dir_plugins = null) {
+	$log = null;
 	if (!$dir_plugins) {
 		$dir_plugins = _DIR_PLUGINS;
 	}
