@@ -14,7 +14,12 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
+/**
+ * @param string $redirect
+ * @return string
+ */
 function securiser_redirect_action($redirect) {
+	$redirect ??= '';
 	// cas d'un double urlencode : si un urldecode de l'url n'est pas secure, on retient ca comme redirect
 	if (strpos($redirect, '%') !== false) {
 		$r2 = urldecode($redirect);
@@ -43,7 +48,6 @@ function securiser_redirect_action($redirect) {
 	return $redirect;
 }
 
-// https://code.spip.net/@traiter_appels_actions
 function traiter_appels_actions() {
 	// cas de l'appel qui renvoie une redirection (302) ou rien (204)
 	if ($action = _request('action')) {
@@ -76,8 +80,8 @@ function traiter_appels_actions() {
 		$var_f = charger_fonction($action, 'action');
 		$var_f();
 		if (!isset($GLOBALS['redirect'])) {
-			$GLOBALS['redirect'] = _request('redirect');
-			if ($_SERVER['REQUEST_METHOD'] == 'POST') {
+			$GLOBALS['redirect'] = _request('redirect') ?? '';
+			if ($_SERVER['REQUEST_METHOD'] === 'POST') {
 				$GLOBALS['redirect'] = urldecode($GLOBALS['redirect']);
 			}
 			$GLOBALS['redirect'] = securiser_redirect_action($GLOBALS['redirect']);
@@ -115,7 +119,6 @@ function traiter_appels_actions() {
 }
 
 
-// https://code.spip.net/@refuser_traiter_formulaire_ajax
 function refuser_traiter_formulaire_ajax() {
 	if (
 		$v = _request('var_ajax')
@@ -134,7 +137,6 @@ function refuser_traiter_formulaire_ajax() {
 	}
 }
 
-// https://code.spip.net/@traiter_appels_inclusions_ajax
 function traiter_appels_inclusions_ajax() {
 	// traiter les appels de bloc ajax (ex: pagination)
 	if (
@@ -160,7 +162,7 @@ function traiter_appels_inclusions_ajax() {
 			}
 		} else {
 			include_spip('inc/headers');
-			http_status(400);
+			http_response_code(400);
 			$texte = _L('signature ajax bloc incorrecte');
 		}
 		ajax_retour($texte, false);
@@ -175,7 +177,6 @@ function traiter_appels_inclusions_ajax() {
 // au 2e se sachant 2e, retourne les messages et erreurs stockes au 1er
 // Le 1er renvoie True si il faut faire exit a la sortie
 
-// https://code.spip.net/@traiter_formulaires_dynamiques
 function traiter_formulaires_dynamiques($get = false) {
 	static $post = [];
 	static $done = false;
@@ -252,7 +253,7 @@ function traiter_formulaires_dynamiques($get = false) {
 			'formulaire_verifier',
 			[
 				'args' => ['form' => $form, 'args' => $args],
-				'data' => $verifier ? call_user_func_array($verifier, $args) : []
+				'data' => $verifier ? $verifier(...$args) : []
 			]
 		);
 		// prise en charge CVT multi etape si besoin
@@ -265,9 +266,9 @@ function traiter_formulaires_dynamiques($get = false) {
 		}
 
 		// accessibilite : si des erreurs mais pas de message general l'ajouter
-		if ((isset($post["erreurs_$form"]) and count($post["erreurs_$form"])) and !isset($post["erreurs_$form"]['message_erreur'])) {
+		if ((isset($post["erreurs_$form"]) and is_countable($post["erreurs_$form"]) ? count($post["erreurs_$form"]) : 0) and !isset($post["erreurs_$form"]['message_erreur'])) {
 			$post["erreurs_$form"]['message_erreur'] = singulier_ou_pluriel(
-				count($post["erreurs_$form"]),
+				is_countable($post["erreurs_$form"]) ? count($post["erreurs_$form"]) : 0,
 				'avis_1_erreur_saisie',
 				'avis_nb_erreurs_saisie'
 			);
@@ -277,15 +278,15 @@ function traiter_formulaires_dynamiques($get = false) {
 		if (_request('formulaire_action_verifier_json')) {
 			include_spip('inc/json');
 			include_spip('inc/actions');
-			ajax_retour(json_encode($post["erreurs_$form"]), 'text/plain');
+			ajax_retour(json_encode($post["erreurs_$form"], JSON_THROW_ON_ERROR), 'text/plain');
 
 			return true; // on a fini le hit
 		}
 		$retour = '';
-		if (isset($post["erreurs_$form"]) and (count($post["erreurs_$form"]) == 0)) {
+		if (isset($post["erreurs_$form"]) and ((is_countable($post["erreurs_$form"]) ? count($post["erreurs_$form"]) : 0) == 0)) {
 			$rev = '';
 			if ($traiter = charger_fonction('traiter', "formulaires/$form/", true)) {
-				$rev = call_user_func_array($traiter, $args);
+				$rev = $traiter(...$args);
 			}
 
 			$rev = pipeline(
@@ -319,7 +320,7 @@ function traiter_formulaires_dynamiques($get = false) {
 				// le bon mode de redirection (302 et on ne revient pas ici, ou javascript et on continue)
 				if (isset($rev['redirect']) and $rev['redirect']) {
 					include_spip('inc/headers');
-					list($masque, $message) = redirige_formulaire($rev['redirect'], '', 'ajaxform');
+					[$masque, $message] = redirige_formulaire($rev['redirect'], '', 'ajaxform');
 					$post["message_ok_$form"] .= $message;
 					$retour .= $masque;
 				}
@@ -330,8 +331,7 @@ function traiter_formulaires_dynamiques($get = false) {
 			if (find_in_path('formulaire_.php', 'balise/', true)) {
 				include_spip('inc/actions');
 				include_spip('public/assembler');
-				array_unshift($args, $form);
-				$retour .= inclure_balise_dynamique(call_user_func_array('balise_formulaire__dyn', $args), false);
+				$retour .= inclure_balise_dynamique(balise_formulaire__dyn($form, ...$args), false);
 				// on ajoute un br en display none en tete du retour ajax pour regler un bug dans IE6/7
 				// sans cela le formulaire n'est pas actif apres le hit ajax
 				// la classe ajax-form-is-ok sert a s'assurer que le retour ajax s'est bien passe
