@@ -57,7 +57,6 @@ include_spip('public/jointures');
 // mais pas pour <INCLURE> dont le fond est defini explicitement.
 
 
-// https://code.spip.net/@argumenter_inclure
 function argumenter_inclure(
 	$params,
 	$rejet_filtres,
@@ -168,6 +167,7 @@ define('CODE_RECUPERER_FOND', 'recuperer_fond(%s, %s, array(%s), %s)');
  **/
 function calculer_inclure($p, &$boucles, $id_boucle) {
 
+	$_options = [];
 	$_contexte = argumenter_inclure($p->param, false, $p, $boucles, $id_boucle, true, '', true);
 	if (is_string($p->texte)) {
 		$fichier = $p->texte;
@@ -240,7 +240,7 @@ function calculer_inclure($p, &$boucles, $id_boucle) {
 			$code,
 			$contexte,
 			implode(',', $_options),
-			'_request("connect")'
+			"_request(\\'connect\\') ?? \\'\\'"
 		) . ';';
 	}
 
@@ -478,6 +478,7 @@ define('CODE_CORPS_BOUCLE', '%s
  **/
 function calculer_boucle_nonrec($id_boucle, &$boucles, $trace) {
 
+	$code_sep = null;
 	$boucle = &$boucles[$id_boucle];
 	$return = $boucle->return;
 	$type_boucle = $boucle->type_requete;
@@ -544,7 +545,7 @@ function calculer_boucle_nonrec($id_boucle, &$boucles, $trace) {
 	}
 
 	// gestion optimale des separateurs et des boucles constantes
-	if (count($boucle->separateur)) {
+	if (is_countable($boucle->separateur) ? count($boucle->separateur) : 0) {
 		$code_sep = ("'" . str_replace("'", "\'", join('', $boucle->separateur)) . "'");
 	}
 
@@ -676,10 +677,11 @@ function calculer_requete_sql($boucle) {
 	$init[] = calculer_dec('join', calculer_dump_join($boucle->join));
 	$init[] = calculer_dec(
 		'limit',
-		(strpos($boucle->limit, 'intval') === false ?
-			"'" . $boucle->limit . "'"
-			:
-		$boucle->limit)
+		(
+			strpos($boucle->limit, 'intval') === false ?
+			"'" . ($boucle->limit) . "'" :
+			$boucle->limit
+		)
 	);
 	$init[] = calculer_dec('having', calculer_dump_array($boucle->having));
 	$s = $d = '';
@@ -719,9 +721,9 @@ function calculer_requete_sql($boucle) {
  **/
 function memoriser_contexte_compil($p) {
 	return join(',', [
-		_q(isset($p->descr['sourcefile']) ? $p->descr['sourcefile'] : ''),
-		_q(isset($p->descr['nom']) ? $p->descr['nom'] : ''),
-		_q(isset($p->id_boucle) ? $p->id_boucle : null),
+		_q($p->descr['sourcefile'] ?? ''),
+		_q($p->descr['nom'] ?? ''),
+		_q($p->id_boucle ?? ''),
 		intval($p->ligne),
 		'$GLOBALS[\'spip_lang\']'
 	]);
@@ -747,12 +749,12 @@ function reconstruire_contexte_compil($context_compil) {
 	}
 	$p = new Contexte();
 	$p->descr = [
-		'sourcefile' => $context_compil[0],
-		'nom' => $context_compil[1]
+		'sourcefile' => $context_compil[0] ?? '',
+		'nom' => $context_compil[1] ?? '',
 	];
-	$p->id_boucle = $context_compil[2];
-	$p->ligne = $context_compil[3];
-	$p->lang = $context_compil[4];
+	$p->id_boucle = $context_compil[2] ?? '';
+	$p->ligne = $context_compil[3] ?? '';
+	$p->lang = $context_compil[4] ?? '';
 
 	return $p;
 }
@@ -836,7 +838,6 @@ function calculer_dump_array($a) {
 	}
 }
 
-// https://code.spip.net/@calculer_dump_join
 function calculer_dump_join($a) {
 	$res = '';
 	foreach ($a as $k => $v) {
@@ -881,7 +882,6 @@ function calculer_from_type(&$boucle) {
 	return 'array(' . substr($res, 1) . ')';
 }
 
-// https://code.spip.net/@calculer_order
 function calculer_order(&$boucle) {
 	if (
 		!$order = $boucle->order
@@ -905,7 +905,6 @@ function calculer_order(&$boucle) {
 // Retourne une expression PHP,
 // (qui sera argument d'un Return ou la partie droite d'une affectation).
 
-// https://code.spip.net/@calculer_liste
 function calculer_liste($tableau, $descr, &$boucles, $id_boucle = '') {
 	if (!$tableau) {
 		return "''";
@@ -932,7 +931,7 @@ function calculer_liste($tableau, $descr, &$boucles, $id_boucle = '') {
 	if ($codes === false) {
 		return false;
 	}
-	$n = count($codes);
+	$n = is_countable($codes) ? count($codes) : 0;
 	if (!$n) {
 		return "''";
 	}
@@ -956,7 +955,7 @@ function calculer_liste($tableau, $descr, &$boucles, $id_boucle = '') {
 			return '(' . substr($res, 2 + $descr['niv']) . ')';
 		}
 	} else {
-		$nom = $descr['nom'] . $id_boucle . ($descr['niv'] ? $descr['niv'] : '');
+		$nom = $descr['nom'] . $id_boucle . ($descr['niv'] ?: '');
 
 		return "join('', array_map('array_shift', \$GLOBALS['debug_objets']['sequence']['$nom'] = array(" . join(
 			" ,\n$tab",
@@ -970,7 +969,6 @@ define('_REGEXP_COND_VIDE_NONVIDE', "/^[(](.*)[?]\s*''\s*:\s*('[^']+')\s*[)]$/")
 define('_REGEXP_COND_NONVIDE_VIDE', "/^[(](.*)[?]\s*('[^']+')\s*:\s*''\s*[)]$/");
 define('_REGEXP_CONCAT_NON_VIDE', "/^(.*)[.]\s*'[^']+'\s*$/");
 
-// https://code.spip.net/@compile_cas
 function compile_cas($tableau, $descr, &$boucles, $id_boucle) {
 
 	$codes = [];
@@ -1203,7 +1201,6 @@ function compile_concatene_parties_codes($partie1, $partie2) {
  * production d'une expression conditionnelle ((v=EXP) ? (p . v .s) : a)
  * mais si EXP est de la forme (t ? 'C' : '') on produit (t ? (p . C . s) : a)
  * de meme si EXP est de la forme (t ? '' : 'C')
- * https://code.spip.net/@compile_retour
  *
  * @param string $code
  *   le code principal, dont le resultat conditionnera le reste
@@ -1287,8 +1284,7 @@ function compile_inclure_doublons($lexemes) {
 // - 'entetes' => tableau des entetes http
 // En cas d'erreur, elle retournera un tableau des 2 premiers elements seulement
 
-// https://code.spip.net/@public_compiler_dist
-function public_compiler_dist($squelette, $nom, $gram, $sourcefile, $connect = '') {
+function public_compiler_dist($squelette, $nom, $gram, $sourcefile, string $connect = '') {
 	// Pre-traitement : reperer le charset du squelette, et le convertir
 	// Bonus : supprime le BOM
 	include_spip('inc/charsets');
@@ -1301,9 +1297,7 @@ function public_compiler_dist($squelette, $nom, $gram, $sourcefile, $connect = '
 	}
 	$squelette = preg_replace_callback(
 		',\\\\([#[()\]{}<>]),',
-		function ($a) use ($inerte) {
-			return "$inerte-" . ord($a[1]) . '-';
-		},
+		fn($a) => "$inerte-" . ord($a[1]) . '-',
 		$squelette,
 		-1,
 		$esc
@@ -1330,16 +1324,12 @@ function public_compiler_dist($squelette, $nom, $gram, $sourcefile, $connect = '
 		foreach ($boucles as $i => $boucle) {
 			$boucles[$i]->return = preg_replace_callback(
 				",$inerte-(\d+)-,",
-				function ($a) {
-					return chr($a[1]);
-				},
+				fn($a) => chr($a[1]),
 				$boucle->return
 			);
 			$boucles[$i]->descr['squelette'] = preg_replace_callback(
 				",$inerte-(\d+)-,",
-				function ($a) {
-					return '\\\\' . chr($a[1]);
-				},
+				fn($a) => '\\\\' . chr($a[1]),
 				$boucle->descr['squelette']
 			);
 		}
@@ -1372,7 +1362,7 @@ function public_compiler_dist($squelette, $nom, $gram, $sourcefile, $connect = '
 // Point d'entree pour arbre de syntaxe abstraite fourni en premier argument
 // Autres specifications comme ci-dessus
 
-function compiler_squelette($squelette, $boucles, $nom, $descr, $sourcefile, $connect = '') {
+function compiler_squelette($squelette, $boucles, $nom, $descr, $sourcefile, string $connect = '') {
 	static $trouver_table;
 	spip_timer('calcul_skel');
 
@@ -1448,7 +1438,7 @@ function compiler_squelette($squelette, $boucles, $nom, $descr, $sourcefile, $co
 					if ($show) {
 						$boucles[$id]->show = $show;
 						// recopie les infos les plus importantes
-						$boucles[$id]->primary = isset($show['key']['PRIMARY KEY']) ? $show['key']['PRIMARY KEY'] : '';
+						$boucles[$id]->primary = $show['key']['PRIMARY KEY'] ?? '';
 						$boucles[$id]->id_table = $x = preg_replace(',^spip_,', '', $show['id_table']);
 						$boucles[$id]->from[$x] = $nom_table = $show['table'];
 						$boucles[$id]->iterateur = 'SQL';
