@@ -68,6 +68,7 @@ defined('_DEBUG_MAX_SQUELETTE_ERREURS') || define('_DEBUG_MAX_SQUELETTE_ERREURS'
  *     - true si $opt 'erreurs' = 'reset'
  **/
 function public_debusquer_dist($message = '', $lieu = '', $opt = []) {
+	static $should_log;
 	static $tableau_des_erreurs = [];
 
 	// Pour des tests unitaires, pouvoir récupérer les erreurs générées
@@ -82,6 +83,10 @@ function public_debusquer_dist($message = '', $lieu = '', $opt = []) {
 		}
 	}
 
+	if (is_null($should_log)) {
+		$should_log = (empty($GLOBALS['visiteur_session']) || !include_spip('inc/autoriser') || !autoriser('debug'));
+	}
+
 	// Erreur ou appel final ?
 	if ($message) {
 		$message = debusquer_compose_message($message);
@@ -92,6 +97,10 @@ function public_debusquer_dist($message = '', $lieu = '', $opt = []) {
 		if (is_object($lieu) and (!isset($lieu->code) or !$lieu->code)) {
 			$lieu->code = "''";
 		}
+		// loger si personne ne verra l'erreur
+		if ($should_log) {
+			debusquer_loger_erreur($message, $lieu);
+		}
 		// forcer l'appel au debusqueur en cas de boucles infernales
 		$urgence = (_DEBUG_MAX_SQUELETTE_ERREURS and (is_countable($tableau_des_erreurs) ? count($tableau_des_erreurs) : 0) > _DEBUG_MAX_SQUELETTE_ERREURS);
 		if (!$urgence) {
@@ -112,7 +121,7 @@ function public_debusquer_dist($message = '', $lieu = '', $opt = []) {
 	include_spip('inc/headers');
 	include_spip('inc/filtres');
 
-	lang_select($GLOBALS['visiteur_session']['lang']);
+	lang_select($GLOBALS['visiteur_session']['lang'] ?? null);
 	$fonc = preg_replace(',\W,', '_', _request('var_mode_objet') ?? '');
 	$mode = preg_replace(',\W,', '_', _request('var_mode_affiche') ?? '');
 
@@ -233,6 +242,28 @@ function debusquer_contexte($env) {
 	return "<div class='spip-env'><fieldset><legend onclick=\"this.parentElement.classList.toggle('expanded');\">#ENV</legend>\n<div><table>$res</table></div></fieldset></div>\n";
 }
 
+
+function debusquer_loger_erreur($msg, $lieu) {
+	$boucle = $ligne = $skel = '';
+	if (is_object($lieu)) {
+		$ligne = ($lieu->ligne ?? '');
+		$boucle = ($lieu->id_boucle ?? '');
+		$skel = ($lieu->descr['sourcefile'] ?? '');
+	}
+	$msg = (is_array($msg) ? implode('', $msg) : $msg);
+	if ($skel) {
+		$msg .= " Squelette $skel";
+	}
+	if ($boucle) {
+		$msg .= " Boucle $boucle";
+	}
+	if ($ligne) {
+		$msg .= " L$ligne";
+	}
+	spip_log($msg, "debusquer" . _LOG_ERREUR);
+}
+
+
 // Affichage du tableau des erreurs ou des temps de calcul
 // Cliquer sur les numeros en premiere colonne permet de voir le code
 
