@@ -455,7 +455,7 @@ class Boucle {
 
 	public $join = [];
 	public $having = [];
-	public $limit;
+	public $limit = '';
 	public $group = [];
 	public $order = [];
 	public $default_order = [];
@@ -942,8 +942,6 @@ $exception_des_connect[] = ''; // ne pas transmettre le connect='' par les inclu
  * et les envoie dans un pipeline
  * pour les plugins
  *
- * @link https://code.spip.net/@declarer_interfaces
- *
  * @return void
  */
 function declarer_interfaces() {
@@ -975,9 +973,9 @@ function declarer_interfaces() {
 	if (!defined('_TRAITEMENT_TYPO_SANS_NUMERO')) {
 		define('_TRAITEMENT_TYPO_SANS_NUMERO', 'supprimer_numero(typo(%s, "TYPO", $connect, $Pile[0]))');
 	}
-	$GLOBALS['table_des_traitements']['BIO'][] = 'safehtml('._TRAITEMENT_RACCOURCIS.')';
+	$GLOBALS['table_des_traitements']['BIO'][] = 'safehtml(' . _TRAITEMENT_RACCOURCIS . ')';
 	$GLOBALS['table_des_traitements']['NOM_SITE']['spip_auteurs'] = 'entites_html(%s)';
-	$GLOBALS['table_des_traitements']['NOM']['spip_auteurs'] = 'safehtml('. _TRAITEMENT_TYPO_SANS_NUMERO.')';
+	$GLOBALS['table_des_traitements']['NOM']['spip_auteurs'] = 'safehtml(' . _TRAITEMENT_TYPO_SANS_NUMERO . ')';
 	$GLOBALS['table_des_traitements']['CHAPO'][] = _TRAITEMENT_RACCOURCIS;
 	$GLOBALS['table_des_traitements']['DATE'][] = 'normaliser_date(%s)';
 	$GLOBALS['table_des_traitements']['DATE_REDAC'][] = 'normaliser_date(%s)';
