@@ -29,8 +29,7 @@ include_fichiers_fonctions();
 
 # En cas d'erreur process_ins est absent et texte est un tableau de 2 chaines
 
-// https://code.spip.net/@public_parametrer_dist
-function public_parametrer_dist($fond, $contexte = '', $cache = '', $connect = '') {
+function public_parametrer_dist($fond, $contexte = '', $cache = '', string $connect = '') {
 	static $composer, $styliser, $notes = null;
 	$page = tester_redirection($fond, $contexte, $connect);
 	if ($page) {
@@ -53,14 +52,14 @@ function public_parametrer_dist($fond, $contexte = '', $cache = '', $connect = '
 	if (!$styliser) {
 		$styliser = charger_fonction('styliser', 'public');
 	}
-	list($skel, $mime_type, $gram, $sourcefile) =
+	[$skel, $mime_type, $gram, $sourcefile] =
 		$styliser($fond, $contexte, $GLOBALS['spip_lang'], $connect);
 
 	if ($skel) {
 		// sauver le nom de l'eventuel squelette en cours d'execution
 		// (recursion possible a cause des modeles)
 		if ($debug) {
-			$courant = @$GLOBALS['debug_objets']['courant'];
+			$courant = $GLOBALS['debug_objets']['courant'] ?? null;
 			$GLOBALS['debug_objets']['contexte'][$sourcefile] = $contexte;
 		}
 
@@ -80,7 +79,7 @@ function public_parametrer_dist($fond, $contexte = '', $cache = '', $connect = '
 	} else {
 		// Preparer l'appel de la fonction principale du squelette
 
-		spip_timer($a = 'calcul page ' . rand(0, 1000));
+		spip_timer($a = 'calcul page ' . random_int(0, 1000));
 
 		// On cree un marqueur de notes unique lie a cette composition
 		// et on enregistre l'etat courant des globales de notes...
@@ -174,7 +173,7 @@ function public_parametrer_dist($fond, $contexte = '', $cache = '', $connect = '
 			if (test_espace_prive() or strncmp($fond, 'modeles/', 8) == 0) {
 				$page['entetes']['X-Spip-Cache'] = 0;
 			} else {
-				$page['entetes']['X-Spip-Cache'] = isset($GLOBALS['delais']) ? $GLOBALS['delais'] : 36000;
+				$page['entetes']['X-Spip-Cache'] = $GLOBALS['delais'] ?? 36000;
 			}
 		}
 
@@ -218,7 +217,9 @@ function presenter_contexte($contexte, $profondeur_max = 1, $max_lines = 0) {
 			$infos[] = '…';
 			break;
 		}
-		if (is_array($val)) {
+		if ($val === null) {
+			$val = '';
+		} elseif (is_array($val)) {
 			if ($profondeur_max > 0) {
 				$val = 'array:' . count($val) . '(' . presenter_contexte($val, $profondeur_max - 1, 3) . ')';
 			} else {
@@ -233,6 +234,8 @@ function presenter_contexte($contexte, $profondeur_max = 1, $max_lines = 0) {
 			}
 		} elseif (strstr($val, ' ')) {
 			$val = "'$val'";
+		} elseif (!strlen($val)) {
+			$val = "''";
 		}
 		$infos[] = $var . '=' . $val;
 	}
@@ -279,7 +282,7 @@ function public_tester_redirection_dist($fond, $contexte, $connect) {
 		and $id_article = intval($contexte['id_article'])
 	) {
 		include_spip('public/quete'); // pour quete_virtuel et ses dependances
-		$m = quete_virtuel($id_article, $connect);
+		$m = quete_virtuel($id_article, $connect) ?? '';
 		if (strlen($m)) {
 			include_spip('inc/texte');
 			// les navigateurs pataugent si l'URL est vide
