@@ -56,7 +56,7 @@ function quete_virtuel($id_article, $connect) {
  * @param string $connect
  * @return array
  */
-function quete_parent_lang($table, $id, $connect = '') {
+function quete_parent_lang($table, $id, string $connect = '') {
 	static $cache_quete = [];
 
 	if (!isset($cache_quete[$connect][$table][$id])) {
@@ -91,7 +91,7 @@ function quete_parent_lang($table, $id, $connect = '') {
 		}
 	}
 
-	return isset($cache_quete[$connect][$table][$id]) ? $cache_quete[$connect][$table][$id] : null;
+	return $cache_quete[$connect][$table][$id] ?? null;
 }
 
 
@@ -107,7 +107,7 @@ function quete_parent_lang($table, $id, $connect = '') {
  * @param string $connect
  * @return int
  */
-function quete_parent($id_rubrique, $connect = '') {
+function quete_parent($id_rubrique, string $connect = '') {
 	if (!$id_rubrique = intval($id_rubrique)) {
 		return 0;
 	}
@@ -143,7 +143,7 @@ function quete_rubrique($id_article, $serveur) {
  * @param string $connect
  * @return int
  */
-function quete_profondeur($id, $connect = '') {
+function quete_profondeur($id, string $connect = '') {
 	$n = 0;
 	while ($id) {
 		$n++;
@@ -487,7 +487,7 @@ function quete_logo_file($row, $connect = null) {
 /**
  * Trouver l'image logo d'un document
  *
- * @param  $row
+ * @param array $row
  *   description du document, issue de la base
  * @param  $lien
  *   url de lien
@@ -507,7 +507,7 @@ function quete_logo_file($row, $connect = null) {
  *   serveur
  * @return string
  */
-function quete_logo_document($row, $lien, $align, $mode_logo, $x, $y, $connect = null) {
+function quete_logo_document($row, $lien, $align, $mode_logo, $x, $y, string $connect = '') {
 
 	include_spip('inc/documents');
 	$logo = '';
@@ -579,8 +579,9 @@ function document_spip_externe($fichier, $connect) {
  * @param string $connect
  * @return string
  */
-function vignette_logo_document($row, $connect = '') {
-	if (!$row['id_vignette']) {
+function vignette_logo_document($row, string $connect = '') {
+
+	if (!$row or empty($row['id_vignette'])) {
 		return '';
 	}
 	$fichier = quete_fichier($row['id_vignette'], $connect);
@@ -596,7 +597,7 @@ function vignette_logo_document($row, $connect = '') {
 		return '';
 	}
 
-	return generer_url_entite($row['id_document'], 'document', '', '', $connect);
+	return generer_objet_url($row['id_document'], 'document', '', '', null, '', $connect);
 }
 
 /**
@@ -611,7 +612,7 @@ function vignette_logo_document($row, $connect = '') {
  * @param string $connect
  * @return bool|string
  */
-function calcul_exposer($id, $prim, $reference, $parent, $type, $connect = '') {
+function calcul_exposer($id, $prim, $reference, $parent, $type, string $connect = '') {
 	static $exposer = [];
 
 	// Que faut-il exposer ? Tous les elements de $reference
@@ -619,10 +620,7 @@ function calcul_exposer($id, $prim, $reference, $parent, $type, $connect = '') {
 	// qu'une fois (par squelette) et on conserve le resultat
 	// en static.
 	if (!isset($exposer[$m = md5(serialize($reference))][$prim])) {
-		$principal = isset($reference[$type]) ? $reference[$type] :
-			// cas de la pagination indecte @xx qui positionne la page avec l'id xx
-			// et donne la reference dynamique @type=xx dans le contexte
-			(isset($reference["@$type"]) ? $reference["@$type"] : '');
+		$principal = $reference[$type] ?? $reference["@$type"] ?? '';
 		// le parent fournit en argument est le parent de $id, pas celui de $principal
 		// il n'est donc pas utile
 		$parent = 0;
@@ -636,7 +634,7 @@ function calcul_exposer($id, $prim, $reference, $parent, $type, $connect = '') {
 						or isset($reference["@$t"])
 					) {
 						$type = $t;
-						$principal = isset($reference[$type]) ? $reference[$type] : $reference["@$type"];
+						$principal = $reference[$type] ?? $reference["@$type"];
 						continue;
 					}
 				}
@@ -707,3 +705,20 @@ function quete_debut_pagination($primary, $valeur, $pas, $iter) {
 	// sinon, calculer le bon numero de page
 	return floor($pos / $pas) * $pas;
 }
+
+/**
+ * Retourne true si ce where doit être appliqué,
+ * dans le cas des critères avec ? tel que `{id_article ?}`
+ *
+ * @param mixed $value
+ * @return boolean
+ */
+function is_whereable($value): bool {
+	if (is_array($value) && count($value)) {
+		return true;
+	}
+	if (is_scalar($value) && strlen($value)) {
+		return true;
+	}
+	return false;
+}
