@@ -15,7 +15,7 @@
  *
  * Une surcharge de ce fichier pourrait permettre :
  *
- * - de limiter l'utilisation des filtres à l'aide d'une liste blanche ou liste noire,
+ * - de limiter l'utilisation des filtres à l'aide d'une liste d’inclusion ou d’exclusion,
  * - de rendre inactif le PHP écrit dans les squelettes
  * - de refuser l'inclusion de fichier PHP dans les squelettes
  *
@@ -182,7 +182,7 @@ function sandbox_filtrer_squelette($skel, $corps, $filtres) {
 	$replace = echapper_php_callback();
 
 	foreach ($series_filtres as $filtres) {
-		if (count($filtres)) {
+		if (is_countable($filtres) ? count($filtres) : 0) {
 			foreach ($filtres as $filtre) {
 				if ($filtre and $f = chercher_filtre($filtre)) {
 					$corps = $f($corps);
