@@ -1727,7 +1727,7 @@ function spip_sqlite_table_exists(string $table, $serveur = '', $requeter = true
 	if (!$requeter) {
 		return $r;
 	}
-	$res = spip_sqlite_fetch($r);
+	$res = spip_sqlite_fetch($r, '', $serveur);
 	return (bool) $res;
 }
 
@@ -2099,7 +2099,7 @@ function _sqlite_calculer_cite($v, $type) {
 			and $l instanceof \PDO
 			and $l->getAttribute(\PDO::ATTR_DRIVER_NAME) === 'sqlite'
 		) {
-			return $l->quote($v);
+			return $l->quote($v ?? '');
 		}
 	}
 
