@@ -842,9 +842,11 @@ function propre_diff($texte) {
  *     Liste des champs versionnés
  */
 function liste_champs_versionnes($table) {
-	$liste_objets_versionnees = is_array(unserialize($GLOBALS['meta']['objets_versions'])) ? unserialize($GLOBALS['meta']['objets_versions']) : [];
+	include_spip('inc/config');
+	$liste_objets_versionnes = lire_config('objets_versions/', []);
+	$liste_objets_versionnes = (is_array($liste_objets_versionnes) ? $liste_objets_versionnes : []);
 
-	if (!in_array($table, $liste_objets_versionnees)) {
+	if (!in_array($table, $liste_objets_versionnes)) {
 		return [];
 	}
 
