@@ -16,7 +16,6 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 
 include_spip('inc/presentation');
 
-// https://code.spip.net/@enfants
 function enfants($id_parent, $critere, &$nombre_branche, &$nombre_rub) {
 	$result = sql_select('id_rubrique', 'spip_rubriques', 'id_parent=' . intval($id_parent));
 
@@ -39,7 +38,6 @@ function enfants($id_parent, $critere, &$nombre_branche, &$nombre_rub) {
 }
 
 
-// https://code.spip.net/@enfants_aff
 function enfants_aff($id_parent, $decalage, $taille, $critere, $gauche = 0) {
 	global $spip_lang_right, $spip_lang_left;
 	static $total_site = null;
@@ -88,7 +86,7 @@ function enfants_aff($id_parent, $decalage, $taille, $critere, $gauche = 0) {
 
 				if ($largeur_branche > 2) {
 					$out .= bouton_block_depliable(
-						"<a href='" . generer_url_entite(
+						"<a href='" . generer_objet_url(
 							$id_rubrique,
 							'rubrique'
 						) . "' style='color: black;' title=\"$descriptif\">$titre</a>",
@@ -97,7 +95,7 @@ function enfants_aff($id_parent, $decalage, $taille, $critere, $gauche = 0) {
 					);
 				} else {
 					$out .= "<div class='rubsimple' style='padding-left: 18px;'>"
-						. "<a href='" . generer_url_entite(
+						. "<a href='" . generer_objet_url(
 							$id_rubrique,
 							'rubrique'
 						) . "' style='color: black;' title=\"$descriptif\">$titre</a>"
