@@ -124,7 +124,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_contributions_hebergees' => '@total_autres@ autre(s) contribution(s) hébergée(s)',
 	'info_critere_phrase' => 'Saisissez les mots-clés à chercher dans le préfixe, le nom, le slogan, la description et les auteurs des plugins',
 	'info_depots_disponibles' => '@total_depots@ dépôt(s)',
-	'info_fichier_depot' => 'Saisissez l’url du fichier de description du dépôt à ajouter.<br />Pour ajouter le dépôt « SPIP-Zone - Plugins » cliquez sur ce lien : ',
+	'info_fichier_depot' => 'Saisissez l’url du fichier de description du dépôt à ajouter.<br />Pour ajouter le dépôt « git.spip.net - extensions » cliquez sur ce lien : ',
 	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
 	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ et @signe_max@ @version_max@',
 	'info_nb_depots' => '@nb@ dépôts',
