@@ -11,6 +11,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// A
 	'action_patienter' => 'Vykonávajú sa akcie. Prosím, počkajte.',
+	'actions' => 'Akcie',
 	'actions_a_faire' => 'Akcie, ktoré treba vykonať',
 	'actions_demandees' => 'Vyžadované akcie:',
 	'actions_en_erreur' => 'Chyby, ktoré sa vyskytli',
@@ -48,20 +49,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// C
 	'cacher_les_plugins_incompatibles' => 'Schovať nekompatibilné zásuvné moduly',
-	'categorie_aucune' => 'Bez kategórie',
-	'categorie_auteur' => 'Prihlásenie, autor, povolenie',
-	'categorie_communication' => 'Komunikácia, interaktivita, odkazovač',
-	'categorie_date' => 'Diáre, kalendár, dátum',
-	'categorie_divers' => 'Nové objekty, externé služby',
-	'categorie_edition' => 'Publikovanie, tlač, písanie',
-	'categorie_maintenance' => 'Konfigurácia, údržba',
-	'categorie_multimedia' => 'Obrázky, galéria, multimédiá',
-	'categorie_navigation' => 'Navigácia, vyhľadávanie, organizácia',
-	'categorie_outil' => 'Nástroj na vývoj',
-	'categorie_performance' => 'Optimalizácia, výkon, bezpečnosť',
-	'categorie_squelette' => 'Šablóna',
-	'categorie_statistique' => 'Odkazovanie, štatistiky',
-	'categorie_theme' => 'Farebný motív',
 	'config_activer_log_verbeux' => 'Aktivovať podrobné protokoly?',
 	'config_activer_log_verbeux_explication' => 'Táto možnosť zabezpečí, že protokoly SVP bud podrobnejšie…',
 	'config_activer_pas_a_pas' => 'Aktivovať režim Krok za krokom?',
@@ -100,7 +87,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 		nebol vytvorený alebo sa doň nedá zapisovať.
 		<strong>Musíte ho vytvoriť, aby ste si pomocou tohto rozhrania mohli nainštalovať nové zásuvné moduly.</strong>',
 	'erreur_dir_plugins_auto_ecriture' => 'Do priečinka s balíkmi @dir@ sa nedá zapisovať. Balík sa nedá spustiť!',
-	'erreur_dir_plugins_auto_indefini' => 'Priečinok _DIR_PLUGIN_AUTO nie je definovaný. Balík sa nedá spustiť!',
+	'erreur_dir_plugins_auto_indefini' => 'Priečinok _DIR_PLUGIN_AUTO nie je definovaný. Balík sa nedá spustiť!', # MODIF
 	'erreur_dir_plugins_auto_titre' => 'K umiestneniu "plugins/auto" sa nedá dostať!',
 	'erreur_teleporter_chargement_source_impossible' => 'Zdroj @source@ sa nedá nahrať',
 	'erreur_teleporter_destination_erreur' => 'Program na premiestňovanie nemá prístup k priečinku @dir@',
@@ -171,14 +158,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_actualise_le' => 'Aktualizovaný',
 	'label_archive' => 'Internetová adresa archívu',
 	'label_branches_spip' => 'Kompatibilný',
-	'label_categorie' => 'Kategória',
 	'label_compatibilite_spip' => 'Kompatibilita',
-	'label_critere_categorie' => 'Kategórie',
 	'label_critere_depot' => 'Depozitáre',
 	'label_critere_doublon' => 'Kompatibilita',
 	'label_critere_etat' => 'Stavy',
 	'label_critere_phrase' => 'Vyhľadávať v zásuvných moduloch',
 	'label_destination' => 'Cesta z priečinka "auto" k zásuvnému modulu',
+	'label_etat' => 'Stav',
 	'label_modifie_le' => 'Zmenený',
 	'label_n_autres_contributions' => 'iné príspevky',
 	'label_prefixe' => 'Predpona',
@@ -262,7 +248,6 @@ alebo vytvoriť tento priečinok a nastaviť mu povolenie na zápis.',
 
 	// O
 	'onglet_depots' => 'Spravovať depozitáre',
-	'option_categorie_toute' => 'Všetky kategórie',
 	'option_depot_tout' => 'Všetky depozitáre',
 	'option_doublon_non' => 'Najnovšia verzia',
 	'option_doublon_oui' => 'Všetky kompatibilné verzie',
@@ -271,7 +256,7 @@ alebo vytvoriť tento priečinok a nastaviť mu povolenie na zápis.',
 	// P
 	'placeholder_phrase' => 'predpona, názov, slogan, opis alebo autor',
 	'plugin_info_actif' => 'Aktívny zásuvný modul',
-	'plugin_info_up' => 'K dispozícii je aktualizácia zásuvného modulu (verzia @version@)',
+	'plugin_info_up' => 'K dispozícii je aktualizácia zásuvného modulu (verzia @version@)', # MODIF
 	'plugin_info_verrouille' => 'Zamknutý zásuvný modul',
 	'plugins_inactifs_liste' => 'Neaktívne',
 	'plugins_non_verrouilles_liste' => 'Nezamknuté',
