@@ -1,7 +1,6 @@
 <?php
 
 // Les URLs brutes sont converties en <a href='url'>url</a>
-// https://code.spip.net/@traiter_raccourci_liens
 function tw_autoliens($t) {
 
 	defined('_EXTRAIRE_LIENS') || define('_EXTRAIRE_LIENS', ',' . '\[[^\[\]]*(?:<-|->).*?\]' . '|<a\b.*?</a\b' . '|<\w.*?>' . '|((?:https?:/|www\.)[^"\'\s\[\]\}\)<>]*)' . ',imsS');
@@ -13,12 +12,11 @@ function tw_autoliens($t) {
 
 
 // callback pour la fonction autoliens()
-// https://code.spip.net/@autoliens_callback
 function tw_traiter_autoliens($r) {
-	if (count($r) < 2) {
+	if ((is_countable($r) ? count($r) : 0) < 2) {
 		return reset($r);
 	}
-	list($tout, $l) = $r;
+	[$tout, $l] = $r;
 	if (!$l) {
 		return $tout;
 	}
@@ -38,7 +36,7 @@ function tw_traiter_autoliens($r) {
 	preg_match('/^(.*?)([,.;?|]?)$/', $l, $k);
 	$url = $protocol . '://' . $k[1];
 	// si l'original ne contenait pas le 'http:' on le supprime du clic
-	$url_echap = echappe_html("<html>". ($m ? $url : substr($url, strlen('http://'))) ."</html>");
+	$url_echap = echappe_html('<html>' . ($m ? $url : substr($url, strlen('http://'))) . '</html>');
 
 
 	$class = 'spip_url';
