@@ -24,7 +24,7 @@ function typographie_en($t) {
 			'&nbsp;' => '~',
 			"'" => '&#8217;'
 		];
-		$charset = isset($GLOBALS['meta']['charset']) ? $GLOBALS['meta']['charset'] : '';
+		$charset = $GLOBALS['meta']['charset'] ?? '';
 		switch ($charset) {
 			case 'utf-8':
 				$trans["\xc2\xa0"] = '~';
